@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -10,10 +10,15 @@
 
 package example.registration;
 
-public class WebClient {
+public class WebClient implements AutoCloseable {
 
 	public WebResponse get(String string) {
 		return new WebResponse();
 	}
 
+	@Override
+	public void close() {
+		/* no-op for demo */
+	}
+
 }
