@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -14,6 +14,7 @@ package example;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.DisplayName;
 import org.junit.jupiter.api.Tag;
@@ -23,10 +24,16 @@ import org.junit.jupiter.api.TestInfo;
 @DisplayName("TestInfo Demo")
 class TestInfoDemo {
 
-	TestInfoDemo(TestInfo testInfo) {
+	@BeforeAll
+	static void beforeAll(TestInfo testInfo) {
 		assertEquals("TestInfo Demo", testInfo.getDisplayName());
 	}
 
+	TestInfoDemo(TestInfo testInfo) {
+		String displayName = testInfo.getDisplayName();
+		assertTrue(displayName.equals("TEST 1") || displayName.equals("test2()"));
+	}
+
 	@BeforeEach
 	void init(TestInfo testInfo) {
 		String displayName = testInfo.getDisplayName();
