@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -11,7 +11,6 @@
 package example.defaultmethods;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 
 import org.junit.jupiter.api.Test;
@@ -30,7 +29,7 @@ public interface EqualsContract<T> extends Testable<T> {
 	@Test
 	default void valueDoesNotEqualNull() {
 		T value = createValue();
-		assertFalse(value.equals(null));
+		assertNotEquals(null, value);
 	}
 
 	@Test
