@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -62,7 +62,7 @@ class EngineTestKitAllEventsDemo {
 						message(m -> m.contains("abc does not contain Z")))),
 				event(test("failingTest"), started()),
 				event(test("failingTest"), finishedWithFailure(
-					instanceOf(ArithmeticException.class), message("/ by zero"))),
+					instanceOf(ArithmeticException.class), message(it -> it.endsWith("by zero")))),
 				event(container(ExampleTestCase.class), finishedSuccessfully()),
 				event(engine(), finishedSuccessfully()));
 	}
