@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -7,6 +7,8 @@
  *
  * https://www.eclipse.org/legal/epl-v20.html
  */
+
+
 package example.registration
 
 import org.junit.jupiter.api.Assertions.assertEquals
@@ -15,13 +17,14 @@ import org.junit.jupiter.api.extension.RegisterExtension
 
 // tag::user_guide[]
 class KotlinWebServerDemo {
-
     companion object {
-        @JvmStatic
+        @JvmField
         @RegisterExtension
-        val server = WebServerExtension.builder()
-            .enableSecurity(false)
-            .build()
+        val server =
+            WebServerExtension
+                .builder()
+                .enableSecurity(false)
+                .build()!!
     }
 
     @Test
