@@ -1,5 +1,6 @@
 plugins {
 	id("junitbuild.kotlin-library-conventions")
+	id("junitbuild.code-generator")
 	`java-test-fixtures`
 }
 
@@ -14,11 +15,17 @@ dependencies {
 
 	compileOnly(kotlin("stdlib"))
 
+	testFixturesImplementation(libs.assertj)
+	testFixturesImplementation(testFixtures(projects.junitPlatformCommons))
+
 	osgiVerification(projects.junitJupiterEngine)
 	osgiVerification(projects.junitPlatformLauncher)
 }
 
 tasks {
+	checkBackwardCompatibility {
+		classExcludes.addAll("*.AssertionsKt\$assert*", "*.AssertionsKt\$evaluate*")
+	}
 	jar {
 		bundle {
 			val version = project.version
