@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -14,6 +14,7 @@ import static org.apiguardian.api.API.Status.INTERNAL;
 
 import org.apiguardian.api.API;
 import org.junit.jupiter.api.Test;
+import org.junit.platform.engine.support.discovery.DiscoveryIssueReporter;
 
 /**
  * Test if a method is a JUnit Jupiter {@link Test @Test} method.
@@ -23,8 +24,8 @@ import org.junit.jupiter.api.Test;
 @API(status = INTERNAL, since = "5.0")
 public class IsTestMethod extends IsTestableMethod {
 
-	public IsTestMethod() {
-		super(Test.class, true);
+	public IsTestMethod(DiscoveryIssueReporter issueReporter) {
+		super(Test.class, IsTestableMethod::hasVoidReturnType, issueReporter);
 	}
 
 }
