@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -17,8 +17,6 @@ import org.junit.jupiter.api.extension.ExtensionContext;
 import org.junit.jupiter.engine.config.JupiterConfiguration;
 import org.junit.jupiter.engine.extension.MutableExtensionRegistry;
 import org.junit.platform.commons.JUnitException;
-import org.junit.platform.commons.logging.Logger;
-import org.junit.platform.commons.logging.LoggerFactory;
 import org.junit.platform.engine.EngineExecutionListener;
 import org.junit.platform.engine.support.hierarchical.EngineExecutionContext;
 import org.junit.platform.engine.support.hierarchical.ThrowableCollector;
@@ -29,17 +27,15 @@ import org.junit.platform.engine.support.hierarchical.ThrowableCollector;
 @API(status = INTERNAL, since = "5.0")
 public class JupiterEngineExecutionContext implements EngineExecutionContext {
 
-	private static final Logger logger = LoggerFactory.getLogger(JupiterEngineExecutionContext.class);
-
 	private final State state;
 
 	// The following is not "cloneable" State.
 	private boolean beforeAllCallbacksExecuted = false;
 	private boolean beforeAllMethodsExecuted = false;
 
-	public JupiterEngineExecutionContext(EngineExecutionListener executionListener,
-			JupiterConfiguration configuration) {
-		this(new State(executionListener, configuration));
+	public JupiterEngineExecutionContext(EngineExecutionListener executionListener, JupiterConfiguration configuration,
+			LauncherStoreFacade launcherStoreFacade) {
+		this(new State(executionListener, configuration, launcherStoreFacade));
 	}
 
 	private JupiterEngineExecutionContext(State state) {
@@ -53,8 +49,7 @@ public class JupiterEngineExecutionContext implements EngineExecutionContext {
 				((AutoCloseable) extensionContext).close();
 			}
 			catch (Exception e) {
-				logger.error(e, () -> "Caught exception while closing extension context: " + extensionContext);
-				throw e;
+				throw new JUnitException("Failed to close extension context", e);
 			}
 		}
 	}
@@ -67,6 +62,10 @@ public class JupiterEngineExecutionContext implements EngineExecutionContext {
 		return this.state.configuration;
 	}
 
+	public LauncherStoreFacade getLauncherStoreFacade() {
+		return this.state.launcherStoreFacade;
+	}
+
 	public TestInstancesProvider getTestInstancesProvider() {
 		return this.state.testInstancesProvider;
 	}
@@ -124,14 +123,17 @@ public class JupiterEngineExecutionContext implements EngineExecutionContext {
 
 		final EngineExecutionListener executionListener;
 		final JupiterConfiguration configuration;
+		final LauncherStoreFacade launcherStoreFacade;
 		TestInstancesProvider testInstancesProvider;
 		MutableExtensionRegistry extensionRegistry;
 		ExtensionContext extensionContext;
 		ThrowableCollector throwableCollector;
 
-		State(EngineExecutionListener executionListener, JupiterConfiguration configuration) {
+		State(EngineExecutionListener executionListener, JupiterConfiguration configuration,
+				LauncherStoreFacade launcherStoreFacade) {
 			this.executionListener = executionListener;
 			this.configuration = configuration;
+			this.launcherStoreFacade = launcherStoreFacade;
 		}
 
 		@Override
