@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -24,26 +24,24 @@ import org.junit.jupiter.api.extension.TestTemplateInvocationContext;
  */
 class RepeatedTestInvocationContext implements TestTemplateInvocationContext {
 
-	private final int currentRepetition;
-	private final int totalRepetitions;
+	private final DefaultRepetitionInfo repetitionInfo;
 	private final RepeatedTestDisplayNameFormatter formatter;
 
-	public RepeatedTestInvocationContext(int currentRepetition, int totalRepetitions,
+	public RepeatedTestInvocationContext(DefaultRepetitionInfo repetitionInfo,
 			RepeatedTestDisplayNameFormatter formatter) {
 
-		this.currentRepetition = currentRepetition;
-		this.totalRepetitions = totalRepetitions;
+		this.repetitionInfo = repetitionInfo;
 		this.formatter = formatter;
 	}
 
 	@Override
 	public String getDisplayName(int invocationIndex) {
-		return this.formatter.format(this.currentRepetition, this.totalRepetitions);
+		return this.formatter.format(this.repetitionInfo.currentRepetition, this.repetitionInfo.totalRepetitions);
 	}
 
 	@Override
 	public List<Extension> getAdditionalExtensions() {
-		return singletonList(new RepetitionInfoParameterResolver(this.currentRepetition, this.totalRepetitions));
+		return singletonList(new RepetitionExtension(this.repetitionInfo));
 	}
 
 }
