@@ -1,7 +1,10 @@
+import junitbuild.extensions.javaModuleName
+
 plugins {
 	id("junitbuild.kotlin-library-conventions")
 	id("junitbuild.shadow-conventions")
-	id("junitbuild.testing-conventions")
+	id("junitbuild.jmh-conventions")
+	`java-test-fixtures`
 }
 
 description = "JUnit Jupiter Params"
@@ -14,15 +17,7 @@ dependencies {
 
 	shadowed(libs.univocity.parsers)
 
-	testImplementation(projects.junitPlatformTestkit)
-	testImplementation(projects.junitJupiterEngine)
-	testImplementation(projects.junitPlatformLauncher)
-	testImplementation(projects.junitPlatformSuiteEngine)
-	testImplementation(testFixtures(projects.junitPlatformCommons))
-	testImplementation(testFixtures(projects.junitJupiterEngine))
-
 	compileOnly(kotlin("stdlib"))
-	testImplementation(kotlin("stdlib"))
 
 	osgiVerification(projects.junitJupiterEngine)
 	osgiVerification(projects.junitPlatformLauncher)
