@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -12,10 +12,10 @@ package org.junit.jupiter.params.provider;
 
 import static org.junit.jupiter.params.provider.Arguments.arguments;
 
-import java.lang.reflect.Method;
 import java.util.stream.Stream;
 
 import org.junit.jupiter.api.extension.ExtensionContext;
+import org.junit.jupiter.params.support.ParameterDeclarations;
 import org.junit.platform.commons.util.Preconditions;
 
 /**
@@ -27,11 +27,10 @@ class NullArgumentsProvider implements ArgumentsProvider {
 	private static final Arguments nullArguments = arguments(new Object[] { null });
 
 	@Override
-	public Stream<? extends Arguments> provideArguments(ExtensionContext context) {
-		Method testMethod = context.getRequiredTestMethod();
-		Preconditions.condition(testMethod.getParameterCount() > 0, () -> String.format(
-			"@NullSource cannot provide a null argument to method [%s]: the method does not declare any formal parameters.",
-			testMethod.toGenericString()));
+	public Stream<? extends Arguments> provideArguments(ParameterDeclarations parameters, ExtensionContext context) {
+		Preconditions.condition(parameters.getFirst().isPresent(),
+			() -> String.format("@NullSource cannot provide a null argument to %s: no formal parameters declared.",
+				parameters.getSourceElementDescription()));
 
 		return Stream.of(nullArguments);
 	}
