@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -49,7 +49,7 @@ public final class UnrecoverableExceptions {
 	 */
 	public static void rethrowIfUnrecoverable(Throwable exception) {
 		if (exception instanceof OutOfMemoryError) {
-			ExceptionUtils.throwAsUncheckedException(exception);
+			throw ExceptionUtils.throwAsUncheckedException(exception);
 		}
 	}
 
