@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -21,6 +21,8 @@ import java.lang.module.ModuleFinder;
 import java.lang.module.ModuleReader;
 import java.lang.module.ModuleReference;
 import java.lang.module.ResolvedModule;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.LinkedHashSet;
@@ -33,8 +35,11 @@ import java.util.stream.Stream;
 
 import org.apiguardian.api.API;
 import org.junit.platform.commons.JUnitException;
+import org.junit.platform.commons.io.Resource;
+import org.junit.platform.commons.io.ResourceFilter;
 import org.junit.platform.commons.logging.Logger;
 import org.junit.platform.commons.logging.LoggerFactory;
+import org.junit.platform.commons.support.scanning.ClassFilter;
 
 /**
  * Collection of utilities for working with {@code java.lang.Module}
@@ -93,7 +98,7 @@ public class ModuleUtils {
 	}
 
 	/**
-	 * Find all classes for the given module name.
+	 * Find all {@linkplain Class classes} for the given module name.
 	 *
 	 * @param moduleName the name of the module to scan; never {@code null} or
 	 * <em>empty</em>
@@ -114,6 +119,30 @@ public class ModuleUtils {
 		return scan(moduleReferences, filter, ModuleUtils.class.getClassLoader());
 	}
 
+	/**
+	 * Find all {@linkplain Resource resources} for the given module name.
+	 *
+	 * @param moduleName the name of the module to scan; never {@code null} or
+	 * <em>empty</em>
+	 * @param filter the class filter to apply; never {@code null}
+	 * @return an immutable list of all such resources found; never {@code null}
+	 * but potentially empty
+	 * @since 1.11
+	 */
+	@API(status = INTERNAL, since = "1.11")
+	public static List<Resource> findAllResourcesInModule(String moduleName, ResourceFilter filter) {
+		Preconditions.notBlank(moduleName, "Module name must not be null or empty");
+		Preconditions.notNull(filter, "Resource filter must not be null");
+
+		logger.debug(() -> "Looking for classes in module: " + moduleName);
+		// @formatter:off
+		Set<ModuleReference> moduleReferences = streamResolvedModules(isEqual(moduleName))
+				.map(ResolvedModule::reference)
+				.collect(toSet());
+		// @formatter:on
+		return scan(moduleReferences, filter, ModuleUtils.class.getClassLoader());
+	}
+
 	/**
 	 * Stream resolved modules from current (or boot) module layer.
 	 */
@@ -146,7 +175,7 @@ public class ModuleUtils {
 	 */
 	private static List<Class<?>> scan(Set<ModuleReference> references, ClassFilter filter, ClassLoader loader) {
 		logger.debug(() -> "Scanning " + references.size() + " module references: " + references);
-		ModuleReferenceScanner scanner = new ModuleReferenceScanner(filter, loader);
+		ModuleReferenceClassScanner scanner = new ModuleReferenceClassScanner(filter, loader);
 		List<Class<?>> classes = new ArrayList<>();
 		for (ModuleReference reference : references) {
 			classes.addAll(scanner.scan(reference));
@@ -156,14 +185,31 @@ public class ModuleUtils {
 	}
 
 	/**
-	 * {@link ModuleReference} scanner.
+	 * Scan for classes using the supplied set of module references, class
+	 * filter, and loader.
 	 */
-	static class ModuleReferenceScanner {
+	private static List<Resource> scan(Set<ModuleReference> references, ResourceFilter filter, ClassLoader loader) {
+		logger.debug(() -> "Scanning " + references.size() + " module references: " + references);
+		ModuleReferenceResourceScanner scanner = new ModuleReferenceResourceScanner(filter, loader);
+		List<Resource> classes = new ArrayList<>();
+		for (ModuleReference reference : references) {
+			classes.addAll(scanner.scan(reference));
+		}
+		logger.debug(() -> "Found " + classes.size() + " classes: " + classes);
+		return Collections.unmodifiableList(classes);
+	}
+
+	/**
+	 * {@link ModuleReference} class scanner.
+	 *
+	 * @since 1.1
+	 */
+	static class ModuleReferenceClassScanner {
 
 		private final ClassFilter classFilter;
 		private final ClassLoader classLoader;
 
-		ModuleReferenceScanner(ClassFilter classFilter, ClassLoader classLoader) {
+		ModuleReferenceClassScanner(ClassFilter classFilter, ClassLoader classLoader) {
 			this.classFilter = classFilter;
 			this.classLoader = classLoader;
 		}
@@ -215,4 +261,50 @@ public class ModuleUtils {
 
 	}
 
+	/**
+	 * {@link ModuleReference} resource class scanner.
+	 *
+	 * @since 1.11
+	 */
+	static class ModuleReferenceResourceScanner {
+
+		private final ResourceFilter resourceFilter;
+		private final ClassLoader classLoader;
+
+		ModuleReferenceResourceScanner(ResourceFilter resourceFilter, ClassLoader classLoader) {
+			this.resourceFilter = resourceFilter;
+			this.classLoader = classLoader;
+		}
+
+		/**
+		 * Scan module reference for resources that potentially contain testable resources.
+		 */
+		List<Resource> scan(ModuleReference reference) {
+			try (ModuleReader reader = reference.open()) {
+				try (Stream<String> names = reader.list()) {
+					// @formatter:off
+					return names.filter(name -> !name.endsWith(".class"))
+							.map(this::loadResourceUnchecked)
+							.filter(resourceFilter::match)
+							.collect(Collectors.toList());
+					// @formatter:on
+				}
+			}
+			catch (IOException e) {
+				throw new JUnitException("Failed to read contents of " + reference + ".", e);
+			}
+		}
+
+		private Resource loadResourceUnchecked(String binaryName) {
+			try {
+				URI uri = classLoader.getResource(binaryName).toURI();
+				return Resource.of(binaryName, uri);
+			}
+			catch (URISyntaxException e) {
+				throw new JUnitException("Failed to load resource with name '" + binaryName + "'.", e);
+			}
+		}
+
+	}
+
 }
