@@ -1,8 +1,10 @@
+import junitbuild.extensions.javaModuleName
+import junitbuild.java.UpdateJarAction
+
 plugins {
 	id("junitbuild.java-library-conventions")
 	id("junitbuild.shadow-conventions")
 	id("junitbuild.java-multi-release-sources")
-	id("junitbuild.java-repackage-jars")
 }
 
 description = "JUnit Platform Console"
@@ -14,6 +16,7 @@ dependencies {
 	compileOnlyApi(libs.apiguardian)
 
 	compileOnly(libs.openTestReporting.events)
+	compileOnly(libs.openTestReporting.tooling.spi)
 
 	shadowed(libs.picocli)
 
@@ -25,7 +28,7 @@ tasks {
 	compileModule {
 		options.compilerArgs.addAll(listOf(
 			"--add-modules", "org.opentest4j.reporting.events",
-			"--add-reads", "${project.projects.junitPlatformReporting.dependencyProject.javaModuleName}=org.opentest4j.reporting.events",
+			"--add-reads", "${project.projects.junitPlatformReporting.javaModuleName}=org.opentest4j.reporting.events",
 			"--add-modules", "info.picocli",
 			"--add-reads", "${javaModuleName}=info.picocli"
 		))
@@ -40,16 +43,21 @@ tasks {
 			into("META-INF")
 		}
 		from(sourceSets.mainRelease9.get().output.classesDirs)
-		doLast(objects.newInstance(junitbuild.java.ExecJarAction::class).apply {
+		doLast(objects.newInstance(UpdateJarAction::class).apply {
 			javaLauncher = project.javaToolchains.launcherFor(java.toolchain)
 			args.addAll(
-				"--update",
 				"--file", archiveFile.get().asFile.absolutePath,
 				"--main-class", "org.junit.platform.console.ConsoleLauncher",
 				"--release", "17",
 				"-C", release17ClassesDir.absolutePath, "."
 			)
 		})
+		bundle {
+			// Ignore warning for package that is only exported as "INTERNAL"
+			bnd("""
+				-fixupmessages.picocli.export: "Export org.junit.platform.console.options";is:=ignore
+			""")
+		}
 	}
 	codeCoverageClassesJar {
 		exclude("org/junit/platform/console/options/ConsoleUtils.class")
