@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -11,8 +11,8 @@
 package org.junit.platform.engine.support.hierarchical;
 
 import static java.util.Collections.emptySet;
-import static org.apiguardian.api.API.Status.EXPERIMENTAL;
 import static org.apiguardian.api.API.Status.MAINTAINED;
+import static org.apiguardian.api.API.Status.STABLE;
 
 import java.util.Optional;
 import java.util.Set;
@@ -132,7 +132,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @param invocation the wrapped invocation (must be invoked exactly once)
 	 * @since 1.4
 	 */
-	@API(status = EXPERIMENTAL, since = "1.4")
+	@API(status = STABLE, since = "1.10")
 	default void around(C context, Invocation<C> invocation) throws Exception {
 		invocation.invoke(context);
 	}
@@ -147,7 +147,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @param result the result of skipped execution
 	 * @since 1.4
 	 */
-	@API(status = EXPERIMENTAL, since = "1.4", consumers = "org.junit.platform.engine.support.hierarchical")
+	@API(status = STABLE, since = "1.10", consumers = "org.junit.platform.engine.support.hierarchical")
 	default void nodeSkipped(C context, TestDescriptor testDescriptor, SkipResult result) {
 	}
 
@@ -161,7 +161,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @param result the result of the execution
 	 * @since 1.4
 	 */
-	@API(status = EXPERIMENTAL, since = "1.4", consumers = "org.junit.platform.engine.support.hierarchical")
+	@API(status = STABLE, since = "1.10", consumers = "org.junit.platform.engine.support.hierarchical")
 	default void nodeFinished(C context, TestDescriptor testDescriptor, TestExecutionResult result) {
 	}
 
@@ -176,7 +176,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @since 1.3
 	 * @see ExclusiveResource
 	 */
-	@API(status = EXPERIMENTAL, since = "1.3", consumers = "org.junit.platform.engine.support.hierarchical")
+	@API(status = STABLE, since = "1.10", consumers = "org.junit.platform.engine.support.hierarchical")
 	default Set<ExclusiveResource> getExclusiveResources() {
 		return emptySet();
 	}
@@ -191,7 +191,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @since 1.3
 	 * @see ExecutionMode
 	 */
-	@API(status = EXPERIMENTAL, since = "1.3", consumers = "org.junit.platform.engine.support.hierarchical")
+	@API(status = STABLE, since = "1.10", consumers = "org.junit.platform.engine.support.hierarchical")
 	default ExecutionMode getExecutionMode() {
 		return ExecutionMode.CONCURRENT;
 	}
@@ -298,10 +298,10 @@ public interface Node<C extends EngineExecutionContext> {
 		 * @param executionListener the executionListener to be notified; never
 		 * {@code null}
 		 * @return a future to cancel or wait for the execution
-		 * @since 5.7
+		 * @since 1.7
 		 * @see EngineExecutionListener#NOOP
 		 */
-		@API(status = EXPERIMENTAL, since = "5.7")
+		@API(status = STABLE, since = "1.10")
 		Future<?> execute(TestDescriptor testDescriptor, EngineExecutionListener executionListener);
 
 		/**
@@ -325,7 +325,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @see #CONCURRENT
 	 * @see Node#getExecutionMode()
 	 */
-	@API(status = EXPERIMENTAL, since = "1.3", consumers = "org.junit.platform.engine.support.hierarchical")
+	@API(status = STABLE, since = "1.10", consumers = "org.junit.platform.engine.support.hierarchical")
 	enum ExecutionMode {
 
 		/**
@@ -349,7 +349,7 @@ public interface Node<C extends EngineExecutionContext> {
 	 * @param <C> the type of {@code EngineExecutionContext} used by the {@code HierarchicalTestEngine}
 	 * @since 1.4
 	 */
-	@API(status = EXPERIMENTAL, since = "1.4")
+	@API(status = STABLE, since = "1.10")
 	interface Invocation<C extends EngineExecutionContext> {
 
 		/**
