@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -158,7 +158,7 @@ public class ThrowableCollector {
 	 */
 	public void assertEmpty() {
 		if (!isEmpty()) {
-			ExceptionUtils.throwAsUncheckedException(this.throwable);
+			throw ExceptionUtils.throwAsUncheckedException(this.throwable);
 		}
 	}
 
