@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -16,6 +16,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
+import org.junit.platform.engine.DiscoveryIssue;
 import org.junit.platform.engine.DiscoverySelector;
 import org.junit.platform.engine.SelectorResolutionResult;
 import org.junit.platform.engine.UniqueId;
@@ -59,4 +60,10 @@ class CompositeLauncherDiscoveryListener implements LauncherDiscoveryListener {
 	public void selectorProcessed(UniqueId engineId, DiscoverySelector selector, SelectorResolutionResult result) {
 		listeners.forEach(delegate -> delegate.selectorProcessed(engineId, selector, result));
 	}
+
+	@Override
+	public void issueEncountered(UniqueId engineId, DiscoveryIssue issue) {
+		listeners.forEach(delegate -> delegate.issueEncountered(engineId, issue));
+	}
+
 }
