@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -21,9 +21,7 @@ import java.util.function.Supplier;
 import org.apiguardian.api.API;
 import org.junit.platform.commons.JUnitException;
 import org.junit.platform.commons.util.Preconditions;
-import org.junit.platform.engine.SelectorResolutionResult.Status;
 import org.junit.platform.engine.TestEngine;
-import org.junit.platform.engine.discovery.UniqueIdSelector;
 import org.junit.platform.launcher.LauncherDiscoveryListener;
 
 /**
@@ -46,13 +44,6 @@ public class LauncherDiscoveryListeners {
 	 *
 	 * <ul>
 	 *     <li>
-	 *         a {@linkplain Status#FAILED failed} resolution result.
-	 *     </li>
-	 *     <li>
-	 *         an {@linkplain Status#FAILED unresolved} resolution result for a
-	 *         {@link UniqueIdSelector} that starts with the engine's unique ID.
-	 *     </li>
-	 *     <li>
 	 *         any recoverable {@link Throwable} thrown by
 	 *         {@link TestEngine#discover}.
 	 *     </li>
