@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -10,7 +10,10 @@
 
 package org.junit.platform.reporting.open.xml;
 
-import static org.apiguardian.api.API.Status.EXPERIMENTAL;
+import static org.apiguardian.api.API.Status.MAINTAINED;
+import static org.junit.platform.commons.util.StringUtils.isNotBlank;
+import static org.junit.platform.launcher.LauncherConstants.STDERR_REPORT_ENTRY_KEY;
+import static org.junit.platform.launcher.LauncherConstants.STDOUT_REPORT_ENTRY_KEY;
 import static org.junit.platform.reporting.open.xml.JUnitFactory.legacyReportingName;
 import static org.junit.platform.reporting.open.xml.JUnitFactory.type;
 import static org.junit.platform.reporting.open.xml.JUnitFactory.uniqueId;
@@ -18,11 +21,13 @@ import static org.opentest4j.reporting.events.core.CoreFactory.attachments;
 import static org.opentest4j.reporting.events.core.CoreFactory.cpuCores;
 import static org.opentest4j.reporting.events.core.CoreFactory.data;
 import static org.opentest4j.reporting.events.core.CoreFactory.directorySource;
+import static org.opentest4j.reporting.events.core.CoreFactory.file;
 import static org.opentest4j.reporting.events.core.CoreFactory.fileSource;
 import static org.opentest4j.reporting.events.core.CoreFactory.hostName;
 import static org.opentest4j.reporting.events.core.CoreFactory.infrastructure;
 import static org.opentest4j.reporting.events.core.CoreFactory.metadata;
 import static org.opentest4j.reporting.events.core.CoreFactory.operatingSystem;
+import static org.opentest4j.reporting.events.core.CoreFactory.output;
 import static org.opentest4j.reporting.events.core.CoreFactory.reason;
 import static org.opentest4j.reporting.events.core.CoreFactory.result;
 import static org.opentest4j.reporting.events.core.CoreFactory.sources;
@@ -30,6 +35,10 @@ import static org.opentest4j.reporting.events.core.CoreFactory.tag;
 import static org.opentest4j.reporting.events.core.CoreFactory.tags;
 import static org.opentest4j.reporting.events.core.CoreFactory.uriSource;
 import static org.opentest4j.reporting.events.core.CoreFactory.userName;
+import static org.opentest4j.reporting.events.git.GitFactory.branch;
+import static org.opentest4j.reporting.events.git.GitFactory.commit;
+import static org.opentest4j.reporting.events.git.GitFactory.repository;
+import static org.opentest4j.reporting.events.git.GitFactory.status;
 import static org.opentest4j.reporting.events.java.JavaFactory.classSource;
 import static org.opentest4j.reporting.events.java.JavaFactory.classpathResourceSource;
 import static org.opentest4j.reporting.events.java.JavaFactory.fileEncoding;
@@ -47,18 +56,20 @@ import java.io.UncheckedIOException;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.nio.file.Path;
+import java.nio.file.Paths;
 import java.time.Instant;
+import java.time.LocalDateTime;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apiguardian.api.API;
 import org.junit.platform.commons.JUnitException;
-import org.junit.platform.commons.util.StringUtils;
 import org.junit.platform.engine.ConfigurationParameters;
 import org.junit.platform.engine.TestExecutionResult;
 import org.junit.platform.engine.TestSource;
 import org.junit.platform.engine.UniqueId;
+import org.junit.platform.engine.reporting.FileEntry;
 import org.junit.platform.engine.reporting.ReportEntry;
 import org.junit.platform.engine.support.descriptor.ClassSource;
 import org.junit.platform.engine.support.descriptor.ClasspathResourceSource;
@@ -71,9 +82,10 @@ import org.junit.platform.engine.support.descriptor.UriSource;
 import org.junit.platform.launcher.TestExecutionListener;
 import org.junit.platform.launcher.TestIdentifier;
 import org.junit.platform.launcher.TestPlan;
-import org.junit.platform.launcher.listeners.OutputDir;
 import org.opentest4j.reporting.events.api.DocumentWriter;
 import org.opentest4j.reporting.events.api.NamespaceRegistry;
+import org.opentest4j.reporting.events.core.Attachments;
+import org.opentest4j.reporting.events.core.Infrastructure;
 import org.opentest4j.reporting.events.core.Result;
 import org.opentest4j.reporting.events.core.Sources;
 import org.opentest4j.reporting.events.root.Events;
@@ -84,17 +96,25 @@ import org.opentest4j.reporting.schema.Namespace;
  *
  * @since 1.9
  */
-@API(status = EXPERIMENTAL, since = "1.9")
+@API(status = MAINTAINED, since = "1.13.3")
 public class OpenTestReportGeneratingListener implements TestExecutionListener {
 
 	static final String ENABLED_PROPERTY_NAME = "junit.platform.reporting.open.xml.enabled";
-	static final String OUTPUT_DIR_PROPERTY_NAME = "junit.platform.reporting.output.dir";
+	static final String GIT_ENABLED_PROPERTY_NAME = "junit.platform.reporting.open.xml.git.enabled";
 
 	private final AtomicInteger idCounter = new AtomicInteger();
 	private final Map<UniqueId, String> inProgressIds = new ConcurrentHashMap<>();
 	private DocumentWriter<Events> eventsFileWriter = DocumentWriter.noop();
+	private final Path workingDir;
+	private Path outputDir;
 
+	@SuppressWarnings("unused") // Used via ServiceLoader
 	public OpenTestReportGeneratingListener() {
+		this(Paths.get(".").toAbsolutePath());
+	}
+
+	OpenTestReportGeneratingListener(Path workingDir) {
+		this.workingDir = workingDir;
 	}
 
 	@Override
@@ -103,15 +123,15 @@ public class OpenTestReportGeneratingListener implements TestExecutionListener {
 		if (isEnabled(config)) {
 			NamespaceRegistry namespaceRegistry = NamespaceRegistry.builder(Namespace.REPORTING_CORE) //
 					.add("e", Namespace.REPORTING_EVENTS) //
+					.add("git", Namespace.REPORTING_GIT) //
 					.add("java", Namespace.REPORTING_JAVA) //
-					.add("junit", JUnitFactory.NAMESPACE,
-						"https://junit.org/junit5/schemas/open-test-reporting/junit-1.9.xsd") //
+					.add("junit", JUnitFactory.NAMESPACE, "https://schemas.junit.org/open-test-reporting/junit-1.9.xsd") //
 					.build();
-			Path eventsXml = OutputDir.create(config.get(OUTPUT_DIR_PROPERTY_NAME)) //
-					.createFile("junit-platform-events", "xml");
+			outputDir = testPlan.getOutputDirectoryCreator().getRootDirectory();
+			Path eventsXml = outputDir.resolve("open-test-report.xml");
 			try {
 				eventsFileWriter = Events.createDocumentWriter(namespaceRegistry, eventsXml);
-				reportInfrastructure();
+				reportInfrastructure(config);
 			}
 			catch (Exception e) {
 				throw new JUnitException("Failed to initialize XML events file: " + eventsXml, e);
@@ -119,11 +139,15 @@ public class OpenTestReportGeneratingListener implements TestExecutionListener {
 		}
 	}
 
-	private Boolean isEnabled(ConfigurationParameters config) {
+	private boolean isEnabled(ConfigurationParameters config) {
 		return config.getBoolean(ENABLED_PROPERTY_NAME).orElse(false);
 	}
 
-	private void reportInfrastructure() {
+	private boolean isGitEnabled(ConfigurationParameters config) {
+		return config.getBoolean(GIT_ENABLED_PROPERTY_NAME).orElse(false);
+	}
+
+	private void reportInfrastructure(ConfigurationParameters config) {
 		eventsFileWriter.append(infrastructure(), infrastructure -> {
 			try {
 				String hostName = InetAddress.getLocalHost().getHostName();
@@ -138,9 +162,26 @@ public class OpenTestReportGeneratingListener implements TestExecutionListener {
 					.append(javaVersion(System.getProperty("java.version"))) //
 					.append(fileEncoding(System.getProperty("file.encoding"))) //
 					.append(heapSize(), heapSize -> heapSize.withMax(Runtime.getRuntime().maxMemory()));
+
+			if (isGitEnabled(config)) {
+				GitInfoCollector.get(workingDir).ifPresent(git -> addGitInfo(infrastructure, git));
+			}
 		});
 	}
 
+	private void addGitInfo(Infrastructure infrastructure, GitInfoCollector git) {
+		git.getOriginUrl() //
+				.ifPresent(
+					gitUrl -> infrastructure.append(repository(), repository -> repository.withOriginUrl(gitUrl)));
+		git.getBranch() //
+				.ifPresent(branch -> infrastructure.append(branch(branch)));
+		git.getCommitHash() //
+				.ifPresent(gitCommitHash -> infrastructure.append(commit(gitCommitHash)));
+		git.getStatus() //
+				.ifPresent(statusOutput -> infrastructure.append(status(statusOutput),
+					status -> status.withClean(statusOutput.isEmpty())));
+	}
+
 	@Override
 	public void testPlanExecutionFinished(TestPlan testPlan) {
 		try {
@@ -160,7 +201,7 @@ public class OpenTestReportGeneratingListener implements TestExecutionListener {
 		reportStarted(testIdentifier, id);
 		eventsFileWriter.append(finished(id, Instant.now()), //
 			finished -> finished.append(result(Result.Status.SKIPPED), result -> {
-				if (StringUtils.isNotBlank(reason)) {
+				if (isNotBlank(reason)) {
 					result.append(reason(reason));
 				}
 			}));
@@ -236,10 +277,38 @@ public class OpenTestReportGeneratingListener implements TestExecutionListener {
 	public void reportingEntryPublished(TestIdentifier testIdentifier, ReportEntry entry) {
 		String id = inProgressIds.get(testIdentifier.getUniqueIdObject());
 		eventsFileWriter.append(reported(id, Instant.now()), //
-			reported -> reported.append(attachments(), attachments -> attachments.append(data(), data -> {
-				data.withTime(entry.getTimestamp());
-				entry.getKeyValuePairs().forEach(data::addEntry);
-			})));
+			reported -> reported.append(attachments(), //
+				attachments -> {
+					Map<String, String> keyValuePairs = entry.getKeyValuePairs();
+					if (keyValuePairs.containsKey(STDOUT_REPORT_ENTRY_KEY)
+							|| keyValuePairs.containsKey(STDERR_REPORT_ENTRY_KEY)) {
+						attachOutput(attachments, entry.getTimestamp(), keyValuePairs.get(STDOUT_REPORT_ENTRY_KEY),
+							"stdout");
+						attachOutput(attachments, entry.getTimestamp(), keyValuePairs.get(STDERR_REPORT_ENTRY_KEY),
+							"stderr");
+					}
+					else {
+						attachments.append(data(entry.getTimestamp()), //
+							data -> keyValuePairs.forEach(data::addEntry));
+					}
+				}));
+	}
+
+	private static void attachOutput(Attachments attachments, LocalDateTime timestamp, String content, String source) {
+		if (content != null) {
+			attachments.append(output(timestamp), output -> output.withSource(source).withContent(content));
+		}
+	}
+
+	@Override
+	public void fileEntryPublished(TestIdentifier testIdentifier, FileEntry entry) {
+		String id = inProgressIds.get(testIdentifier.getUniqueIdObject());
+		eventsFileWriter.append(reported(id, Instant.now()), //
+			reported -> reported.append(attachments(), attachments -> attachments.append(file(entry.getTimestamp()), //
+				file -> {
+					file.withPath(outputDir.relativize(entry.getPath()).toString());
+					entry.getMediaType().ifPresent(file::withMediaType);
+				})));
 	}
 
 	@Override
