@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -11,8 +11,10 @@
 package org.junit.platform.suite.commons;
 
 import static java.util.stream.Collectors.toList;
-import static org.junit.platform.commons.util.AnnotationUtils.findAnnotation;
-import static org.junit.platform.commons.util.AnnotationUtils.findRepeatableAnnotations;
+import static org.apiguardian.api.API.Status.DEPRECATED;
+import static org.apiguardian.api.API.Status.INTERNAL;
+import static org.junit.platform.commons.support.AnnotationSupport.findAnnotation;
+import static org.junit.platform.commons.support.AnnotationSupport.findRepeatableAnnotations;
 import static org.junit.platform.engine.discovery.ClassNameFilter.STANDARD_INCLUDE_PATTERN;
 import static org.junit.platform.suite.commons.AdditionalDiscoverySelectors.selectClasspathResource;
 import static org.junit.platform.suite.commons.AdditionalDiscoverySelectors.selectFile;
@@ -30,22 +32,24 @@ import java.util.regex.Pattern;
 import java.util.stream.Stream;
 
 import org.apiguardian.api.API;
-import org.apiguardian.api.API.Status;
 import org.junit.platform.commons.util.Preconditions;
 import org.junit.platform.commons.util.StringUtils;
 import org.junit.platform.engine.ConfigurationParameters;
 import org.junit.platform.engine.DiscoverySelector;
 import org.junit.platform.engine.Filter;
+import org.junit.platform.engine.OutputDirectoryCreator;
 import org.junit.platform.engine.discovery.ClassNameFilter;
 import org.junit.platform.engine.discovery.ClassSelector;
 import org.junit.platform.engine.discovery.DiscoverySelectors;
 import org.junit.platform.engine.discovery.MethodSelector;
 import org.junit.platform.engine.discovery.PackageNameFilter;
 import org.junit.platform.launcher.EngineFilter;
+import org.junit.platform.launcher.LauncherDiscoveryListener;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
 import org.junit.platform.launcher.TagFilter;
 import org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder;
 import org.junit.platform.suite.api.ConfigurationParameter;
+import org.junit.platform.suite.api.ConfigurationParametersResource;
 import org.junit.platform.suite.api.DisableParentConfigurationParameters;
 import org.junit.platform.suite.api.ExcludeClassNamePatterns;
 import org.junit.platform.suite.api.ExcludeEngines;
@@ -55,6 +59,7 @@ import org.junit.platform.suite.api.IncludeClassNamePatterns;
 import org.junit.platform.suite.api.IncludeEngines;
 import org.junit.platform.suite.api.IncludePackages;
 import org.junit.platform.suite.api.IncludeTags;
+import org.junit.platform.suite.api.Select;
 import org.junit.platform.suite.api.SelectClasses;
 import org.junit.platform.suite.api.SelectClasspathResource;
 import org.junit.platform.suite.api.SelectDirectories;
@@ -108,8 +113,7 @@ import org.junit.platform.suite.api.SelectUris;
  * @see org.junit.platform.launcher.EngineFilter
  * @see org.junit.platform.launcher.TagFilter
  */
-@API(status = Status.INTERNAL, since = "1.8", consumers = { "org.junit.platform.suite.engine",
-		"org.junit.platform.runner" })
+@API(status = INTERNAL, since = "1.8", consumers = { "org.junit.platform.suite.engine", "org.junit.platform.runner" })
 public final class SuiteLauncherDiscoveryRequestBuilder {
 
 	private final LauncherDiscoveryRequestBuilder delegate = LauncherDiscoveryRequestBuilder.request();
@@ -213,6 +217,11 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 		return this;
 	}
 
+	public SuiteLauncherDiscoveryRequestBuilder configurationParametersResource(String resourceFile) {
+		this.delegate.configurationParametersResources(resourceFile);
+		return this;
+	}
+
 	/**
 	 * Set the parent configuration parameters to use for the request.
 	 *
@@ -254,6 +263,17 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 		return this;
 	}
 
+	public SuiteLauncherDiscoveryRequestBuilder outputDirectoryCreator(OutputDirectoryCreator outputDirectoryCreator) {
+		delegate.outputDirectoryCreator(outputDirectoryCreator);
+		return this;
+	}
+
+	@API(status = INTERNAL, since = "1.13")
+	public SuiteLauncherDiscoveryRequestBuilder listener(LauncherDiscoveryListener listener) {
+		delegate.listeners(listener);
+		return this;
+	}
+
 	/**
 	 * Apply a suite's annotation-based configuration, selectors, and filters to
 	 * this builder.
@@ -266,6 +286,7 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 	 * {@link #applySelectorsAndFiltersFromSuite}
 	 */
 	@Deprecated
+	@API(status = DEPRECATED, since = "1.11")
 	public SuiteLauncherDiscoveryRequestBuilder suite(Class<?> suiteClass) {
 		Preconditions.notNull(suiteClass, "Suite class must not be null");
 		applyConfigurationParametersFromSuite(suiteClass);
@@ -294,6 +315,8 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 		// @formatter:off
 		findRepeatableAnnotations(suiteClass, ConfigurationParameter.class)
 				.forEach(configuration -> configurationParameter(configuration.key(), configuration.value()));
+		findRepeatableAnnotations(suiteClass, ConfigurationParametersResource.class)
+				.forEach(configResource -> configurationParametersResource(configResource.value()));
 		findAnnotation(suiteClass, DisableParentConfigurationParameters.class)
 				.ifPresent(__ -> this.enableParentConfigurationParameters = false);
 		// @formatter:on
@@ -322,6 +345,7 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 	 *   <li>{@link SelectModules}</li>
 	 *   <li>{@link SelectUris}</li>
 	 *   <li>{@link SelectPackages}</li>
+	 *   <li>{@link Select}</li>
 	 * </ul>
 	 *
 	 * @param suiteClass the class to apply the discovery selectors and filter
@@ -333,68 +357,84 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 	public SuiteLauncherDiscoveryRequestBuilder applySelectorsAndFiltersFromSuite(Class<?> suiteClass) {
 		Preconditions.notNull(suiteClass, "Suite class must not be null");
 
-		// Annotations in alphabetical order (except @SelectClasses)
-		// @formatter:off
-		findAnnotationValues(suiteClass, ExcludeClassNamePatterns.class, ExcludeClassNamePatterns::value)
-				.flatMap(SuiteLauncherDiscoveryRequestBuilder::trimmed)
-				.map(ClassNameFilter::excludeClassNamePatterns)
-				.ifPresent(this::filters);
-		findAnnotationValues(suiteClass, ExcludeEngines.class, ExcludeEngines::value)
-				.map(EngineFilter::excludeEngines)
-				.ifPresent(this::filters);
-		findAnnotationValues(suiteClass, ExcludePackages.class, ExcludePackages::value)
-				.map(PackageNameFilter::excludePackageNames)
-				.ifPresent(this::filters);
-		findAnnotationValues(suiteClass, ExcludeTags.class, ExcludeTags::value)
-				.map(TagFilter::excludeTags)
-				.ifPresent(this::filters);
-		// Process @SelectClasses before @IncludeClassNamePatterns, since the names
+		addExcludeFilters(suiteClass);
+		// Process @SelectClasses and @SelectMethod before @IncludeClassNamePatterns, since the names
 		// of selected classes get automatically added to the include filter.
-		findAnnotation(suiteClass, SelectClasses.class)
-				.map(annotation -> selectClasses(suiteClass, annotation))
+		addClassAndMethodSelectors(suiteClass);
+		addIncludeFilters(suiteClass);
+		addOtherSelectors(suiteClass);
+		return this;
+	}
+
+	private void addExcludeFilters(Class<?> suiteClass) {
+		findAnnotationValues(suiteClass, ExcludeClassNamePatterns.class, ExcludeClassNamePatterns::value) //
+				.flatMap(SuiteLauncherDiscoveryRequestBuilder::trimmed) //
+				.map(ClassNameFilter::excludeClassNamePatterns) //
+				.ifPresent(this::filters);
+		findAnnotationValues(suiteClass, ExcludeEngines.class, ExcludeEngines::value) //
+				.map(EngineFilter::excludeEngines) //
+				.ifPresent(this::filters);
+		findAnnotationValues(suiteClass, ExcludePackages.class, ExcludePackages::value) //
+				.map(PackageNameFilter::excludePackageNames) //
+				.ifPresent(this::filters);
+		findAnnotationValues(suiteClass, ExcludeTags.class, ExcludeTags::value) //
+				.map(TagFilter::excludeTags) //
+				.ifPresent(this::filters);
+	}
+
+	private void addClassAndMethodSelectors(Class<?> suiteClass) {
+		findAnnotation(suiteClass, SelectClasses.class) //
+				.map(annotation -> selectClasses(suiteClass, annotation)) //
 				.ifPresent(this::selectors);
-		findRepeatableAnnotations(suiteClass, SelectMethod.class)
-				.stream()
-				.map(annotation -> selectMethod(suiteClass, annotation))
+		findRepeatableAnnotations(suiteClass, SelectMethod.class) //
+				.stream() //
+				.map(annotation -> selectMethod(suiteClass, annotation)) //
 				.forEach(this::selectors);
-		findAnnotationValues(suiteClass, IncludeClassNamePatterns.class, IncludeClassNamePatterns::value)
-				.flatMap(SuiteLauncherDiscoveryRequestBuilder::trimmed)
-				.map(this::createIncludeClassNameFilter)
+	}
+
+	private void addIncludeFilters(Class<?> suiteClass) {
+		findAnnotationValues(suiteClass, IncludeClassNamePatterns.class, IncludeClassNamePatterns::value) //
+				.flatMap(SuiteLauncherDiscoveryRequestBuilder::trimmed) //
+				.map(this::createIncludeClassNameFilter) //
 				.ifPresent(filters -> {
 					this.includeClassNamePatternsUsed = true;
 					filters(filters);
 				});
-		findAnnotationValues(suiteClass, IncludeEngines.class, IncludeEngines::value)
-				.map(EngineFilter::includeEngines)
+		findAnnotationValues(suiteClass, IncludeEngines.class, IncludeEngines::value) //
+				.map(EngineFilter::includeEngines) //
 				.ifPresent(this::filters);
-		findAnnotationValues(suiteClass, IncludePackages.class, IncludePackages::value)
-				.map(PackageNameFilter::includePackageNames)
+		findAnnotationValues(suiteClass, IncludePackages.class, IncludePackages::value) //
+				.map(PackageNameFilter::includePackageNames) //
 				.ifPresent(this::filters);
-		findAnnotationValues(suiteClass, IncludeTags.class, IncludeTags::value)
-				.map(TagFilter::includeTags)
+		findAnnotationValues(suiteClass, IncludeTags.class, IncludeTags::value) //
+				.map(TagFilter::includeTags) //
 				.ifPresent(this::filters);
-		findRepeatableAnnotations(suiteClass, SelectClasspathResource.class)
-				.stream()
-				.map(annotation -> selectClasspathResource(annotation.value(), annotation.line(), annotation.column()))
+	}
+
+	private void addOtherSelectors(Class<?> suiteClass) {
+		findRepeatableAnnotations(suiteClass, SelectClasspathResource.class) //
+				.stream() //
+				.map(annotation -> selectClasspathResource(annotation.value(), annotation.line(), annotation.column())) //
 				.forEach(this::selectors);
-		findAnnotationValues(suiteClass, SelectDirectories.class, SelectDirectories::value)
-				.map(AdditionalDiscoverySelectors::selectDirectories)
+		findAnnotationValues(suiteClass, SelectDirectories.class, SelectDirectories::value) //
+				.map(AdditionalDiscoverySelectors::selectDirectories) //
 				.ifPresent(this::selectors);
-		findRepeatableAnnotations(suiteClass, SelectFile.class)
-				.stream()
-				.map(annotation -> selectFile(annotation.value(), annotation.line(), annotation.column()))
+		findRepeatableAnnotations(suiteClass, SelectFile.class) //
+				.stream() //
+				.map(annotation -> selectFile(annotation.value(), annotation.line(), annotation.column())) //
 				.forEach(this::selectors);
-		findAnnotationValues(suiteClass, SelectModules.class, SelectModules::value)
-				.map(AdditionalDiscoverySelectors::selectModules)
+		findAnnotationValues(suiteClass, SelectModules.class, SelectModules::value) //
+				.map(AdditionalDiscoverySelectors::selectModules) //
 				.ifPresent(this::selectors);
-		findAnnotationValues(suiteClass, SelectUris.class, SelectUris::value)
-				.map(AdditionalDiscoverySelectors::selectUris)
+		findAnnotationValues(suiteClass, SelectUris.class, SelectUris::value) //
+				.map(AdditionalDiscoverySelectors::selectUris) //
 				.ifPresent(this::selectors);
-		findAnnotationValues(suiteClass, SelectPackages.class, SelectPackages::value)
-				.map(AdditionalDiscoverySelectors::selectPackages)
+		findAnnotationValues(suiteClass, SelectPackages.class, SelectPackages::value) //
+				.map(AdditionalDiscoverySelectors::selectPackages) //
+				.ifPresent(this::selectors);
+		findAnnotationValues(suiteClass, Select.class, Select::value) //
+				.map(AdditionalDiscoverySelectors::parseIdentifiers) //
 				.ifPresent(this::selectors);
-		// @formatter:on
-		return this;
 	}
 
 	/**
@@ -438,23 +478,7 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 
 	private MethodSelector toMethodSelector(Class<?> suiteClass, SelectMethod annotation) {
 		if (!annotation.value().isEmpty()) {
-			Preconditions.condition(annotation.type() == Class.class,
-				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
-					"type must not be set in conjunction with fully qualified method name"));
-			Preconditions.condition(annotation.typeName().isEmpty(),
-				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
-					"type name must not be set in conjunction with fully qualified method name"));
-			Preconditions.condition(annotation.name().isEmpty(),
-				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
-					"method name must not be set in conjunction with fully qualified method name"));
-			Preconditions.condition(annotation.parameterTypes().length == 0,
-				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
-					"parameter types must not be set in conjunction with fully qualified method name"));
-			Preconditions.condition(annotation.parameterTypeNames().isEmpty(),
-				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
-					"parameter type names must not be set in conjunction with fully qualified method name"));
-
-			return DiscoverySelectors.selectMethod(annotation.value());
+			return toMethodSelectorFromFQMN(suiteClass, annotation);
 		}
 
 		Class<?> type = annotation.type() == Class.class ? null : annotation.type();
@@ -468,25 +492,44 @@ public final class SuiteLauncherDiscoveryRequestBuilder {
 				() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
 					"either parameter type names or parameter types must be set but not both"));
 		}
+		return toMethodSelector(suiteClass, type, typeName, parameterTypes, methodName, parameterTypeNames);
+	}
+
+	private static MethodSelector toMethodSelectorFromFQMN(Class<?> suiteClass, SelectMethod annotation) {
+		Preconditions.condition(annotation.type() == Class.class,
+			() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
+				"type must not be set in conjunction with fully qualified method name"));
+		Preconditions.condition(annotation.typeName().isEmpty(),
+			() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
+				"type name must not be set in conjunction with fully qualified method name"));
+		Preconditions.condition(annotation.name().isEmpty(),
+			() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
+				"method name must not be set in conjunction with fully qualified method name"));
+		Preconditions.condition(annotation.parameterTypes().length == 0,
+			() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
+				"parameter types must not be set in conjunction with fully qualified method name"));
+		Preconditions.condition(annotation.parameterTypeNames().isEmpty(),
+			() -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
+				"parameter type names must not be set in conjunction with fully qualified method name"));
+
+		return DiscoverySelectors.selectMethod(annotation.value());
+	}
+
+	private static MethodSelector toMethodSelector(Class<?> suiteClass, Class<?> type, String typeName,
+			Class<?>[] parameterTypes, String methodName, String parameterTypeNames) {
 		if (type == null) {
 			Preconditions.notBlank(typeName, () -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
 				"type must be set or type name must not be blank"));
-			if (parameterTypes == null) {
-				return DiscoverySelectors.selectMethod(typeName, methodName, parameterTypeNames);
-			}
-			else {
-				return DiscoverySelectors.selectMethod(typeName, methodName, parameterTypes);
-			}
+			return parameterTypes == null //
+					? DiscoverySelectors.selectMethod(typeName, methodName, parameterTypeNames) //
+					: DiscoverySelectors.selectMethod(typeName, methodName, parameterTypes);
 		}
 		else {
 			Preconditions.condition(typeName == null, () -> prefixErrorMessageForInvalidSelectMethodUsage(suiteClass,
 				"either type name or type must be set but not both"));
-			if (parameterTypes == null) {
-				return DiscoverySelectors.selectMethod(type, methodName, parameterTypeNames);
-			}
-			else {
-				return DiscoverySelectors.selectMethod(type, methodName, parameterTypes);
-			}
+			return parameterTypes == null //
+					? DiscoverySelectors.selectMethod(type, methodName, parameterTypeNames) //
+					: DiscoverySelectors.selectMethod(type, methodName, parameterTypes);
 		}
 	}
 
