@@ -12,3 +12,7 @@ dependencies {
 	osgiVerification(projects.junitJupiterEngine)
 	osgiVerification(projects.junitPlatformLauncher)
 }
+
+japicmp {
+	enabled = false // already checked by individual projects
+}
