@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -15,25 +15,33 @@ import static java.util.Collections.singleton;
 import static org.apiguardian.api.API.Status.DEPRECATED;
 import static org.apiguardian.api.API.Status.MAINTAINED;
 import static org.apiguardian.api.API.Status.STABLE;
-import static org.junit.platform.launcher.core.EngineDiscoveryOrchestrator.Phase.EXECUTION;
+import static org.junit.platform.engine.support.store.NamespacedHierarchicalStore.CloseAction.closeAutoCloseables;
 
+import java.nio.file.Path;
+import java.util.List;
 import java.util.Map;
 import java.util.ServiceLoader;
+import java.util.function.Consumer;
 import java.util.stream.Stream;
 
 import org.apiguardian.api.API;
+import org.junit.platform.commons.JUnitException;
 import org.junit.platform.commons.PreconditionViolationException;
 import org.junit.platform.commons.util.CollectionUtils;
 import org.junit.platform.commons.util.Preconditions;
 import org.junit.platform.engine.DiscoveryFilter;
+import org.junit.platform.engine.DiscoveryIssue;
 import org.junit.platform.engine.DiscoverySelector;
 import org.junit.platform.engine.EngineDiscoveryRequest;
 import org.junit.platform.engine.EngineExecutionListener;
 import org.junit.platform.engine.ExecutionRequest;
 import org.junit.platform.engine.Filter;
+import org.junit.platform.engine.OutputDirectoryCreator;
 import org.junit.platform.engine.TestDescriptor;
 import org.junit.platform.engine.TestEngine;
 import org.junit.platform.engine.UniqueId;
+import org.junit.platform.engine.support.store.Namespace;
+import org.junit.platform.engine.support.store.NamespacedHierarchicalStore;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
 import org.junit.platform.launcher.core.EngineDiscoveryOrchestrator;
 import org.junit.platform.launcher.core.EngineExecutionOrchestrator;
@@ -42,15 +50,24 @@ import org.junit.platform.launcher.core.LauncherDiscoveryResult;
 import org.junit.platform.launcher.core.ServiceLoaderTestEngineRegistry;
 
 /**
- * {@code EngineTestKit} provides support for executing a test plan for a given
- * {@link TestEngine} and then accessing the results via
- * {@linkplain EngineExecutionResults a fluent API} to verify the expected results.
+ * {@code EngineTestKit} provides support for discovering and executing tests
+ * for a given {@link TestEngine} and provides convenient access to the results.
+ *
+ * <p>For <em>discovery</em>, {@link EngineDiscoveryResults} provides access to
+ * the {@link TestDescriptor} of the engine and any {@link DiscoveryIssue
+ * DiscoveryIssues} that were encountered.
+ *
+ * <p>For <em>execution</em>, {@link EngineExecutionResults} provides a fluent
+ * API to verify the expected results.
  *
  * @since 1.4
  * @see #engine(String)
  * @see #engine(TestEngine)
+ * @see #discover(String, LauncherDiscoveryRequest)
+ * @see #discover(TestEngine, LauncherDiscoveryRequest)
  * @see #execute(String, LauncherDiscoveryRequest)
  * @see #execute(TestEngine, LauncherDiscoveryRequest)
+ * @see EngineDiscoveryResults
  * @see EngineExecutionResults
  */
 @API(status = MAINTAINED, since = "1.7")
@@ -117,6 +134,65 @@ public final class EngineTestKit {
 		return new Builder(testEngine);
 	}
 
+	/**
+	 * Discover tests for the given {@link LauncherDiscoveryRequest} using the
+	 * {@link TestEngine} with the supplied ID.
+	 *
+	 * <p>The {@code TestEngine} will be loaded via Java's {@link ServiceLoader}
+	 * mechanism, analogous to the manner in which test engines are loaded in
+	 * the JUnit Platform Launcher API.
+	 *
+	 * <p>{@link org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder}
+	 * provides a convenient way to build an appropriate discovery request to
+	 * supply to this method. As an alternative, consider using
+	 * {@link #engine(TestEngine)} for a more fluent API.
+	 *
+	 * @param engineId the ID of the {@code TestEngine} to use; must not be
+	 * {@code null} or <em>blank</em>
+	 * @param discoveryRequest the {@code LauncherDiscoveryRequest} to use
+	 * @return the results of the discovery
+	 * @throws PreconditionViolationException for invalid arguments or if the
+	 * {@code TestEngine} with the supplied ID cannot be loaded
+	 * @since 1.13
+	 * @see #discover(TestEngine, LauncherDiscoveryRequest)
+	 * @see #engine(String)
+	 * @see #engine(TestEngine)
+	 */
+	@API(status = MAINTAINED, since = "1.13.3")
+	public static EngineDiscoveryResults discover(String engineId, LauncherDiscoveryRequest discoveryRequest) {
+		Preconditions.notBlank(engineId, "TestEngine ID must not be null or blank");
+		return discover(loadTestEngine(engineId.trim()), discoveryRequest);
+	}
+
+	/**
+	 * Discover tests for the given {@link LauncherDiscoveryRequest} using the
+	 * supplied {@link TestEngine}.
+	 *
+	 * <p>{@link org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder}
+	 * provides a convenient way to build an appropriate discovery request to
+	 * supply to this method. As an alternative, consider using
+	 * {@link #engine(TestEngine)} for a more fluent API.
+	 *
+	 * @param testEngine the {@code TestEngine} to use; must not be {@code null}
+	 * @param discoveryRequest the {@code EngineDiscoveryResults} to use; must
+	 * not be {@code null}
+	 * @return the recorded {@code EngineExecutionResults}
+	 * @throws PreconditionViolationException for invalid arguments
+	 * @since 1.13
+	 * @see #discover(String, LauncherDiscoveryRequest)
+	 * @see #engine(String)
+	 * @see #engine(TestEngine)
+	 */
+	@API(status = MAINTAINED, since = "1.13.3")
+	public static EngineDiscoveryResults discover(TestEngine testEngine, LauncherDiscoveryRequest discoveryRequest) {
+		Preconditions.notNull(testEngine, "TestEngine must not be null");
+		Preconditions.notNull(discoveryRequest, "EngineDiscoveryRequest must not be null");
+		LauncherDiscoveryResult discoveryResult = discoverUsingOrchestrator(testEngine, discoveryRequest);
+		TestDescriptor engineDescriptor = discoveryResult.getEngineTestDescriptor(testEngine);
+		List<DiscoveryIssue> discoveryIssues = discoveryResult.getDiscoveryIssues(testEngine);
+		return new EngineDiscoveryResults(engineDescriptor, discoveryIssues);
+	}
+
 	/**
 	 * Execute tests for the given {@link EngineDiscoveryRequest} using the
 	 * {@link TestEngine} with the supplied ID.
@@ -249,18 +325,36 @@ public final class EngineTestKit {
 			EngineExecutionListener listener) {
 		UniqueId engineUniqueId = UniqueId.forEngine(testEngine.getId());
 		TestDescriptor engineTestDescriptor = testEngine.discover(discoveryRequest, engineUniqueId);
-		ExecutionRequest request = new ExecutionRequest(engineTestDescriptor, listener,
-			discoveryRequest.getConfigurationParameters());
-		testEngine.execute(request);
+		withRequestLevelStore(store -> {
+			ExecutionRequest request = ExecutionRequest.create(engineTestDescriptor, listener,
+				discoveryRequest.getConfigurationParameters(), discoveryRequest.getOutputDirectoryCreator(), store);
+			testEngine.execute(request);
+		});
 	}
 
 	private static void executeUsingLauncherOrchestration(TestEngine testEngine,
 			LauncherDiscoveryRequest discoveryRequest, EngineExecutionListener listener) {
-		LauncherDiscoveryResult discoveryResult = new EngineDiscoveryOrchestrator(singleton(testEngine),
-			emptySet()).discover(discoveryRequest, EXECUTION);
+		LauncherDiscoveryResult discoveryResult = discoverUsingOrchestrator(testEngine, discoveryRequest);
 		TestDescriptor engineTestDescriptor = discoveryResult.getEngineTestDescriptor(testEngine);
 		Preconditions.notNull(engineTestDescriptor, "TestEngine did not yield a TestDescriptor");
-		new EngineExecutionOrchestrator().execute(discoveryResult, listener);
+		withRequestLevelStore(store -> new EngineExecutionOrchestrator().execute(discoveryResult, listener, store));
+	}
+
+	private static void withRequestLevelStore(Consumer<NamespacedHierarchicalStore<Namespace>> action) {
+		try (NamespacedHierarchicalStore<Namespace> sessionLevelStore = newStore(null);
+				NamespacedHierarchicalStore<Namespace> requestLevelStore = newStore(sessionLevelStore)) {
+			action.accept(requestLevelStore);
+		}
+	}
+
+	private static NamespacedHierarchicalStore<Namespace> newStore(NamespacedHierarchicalStore<Namespace> parentStore) {
+		return new NamespacedHierarchicalStore<>(parentStore, closeAutoCloseables());
+	}
+
+	private static LauncherDiscoveryResult discoverUsingOrchestrator(TestEngine testEngine,
+			LauncherDiscoveryRequest discoveryRequest) {
+		return new EngineDiscoveryOrchestrator(singleton(testEngine), emptySet()) //
+				.discover(discoveryRequest);
 	}
 
 	@SuppressWarnings("unchecked")
@@ -295,7 +389,8 @@ public final class EngineTestKit {
 	public static final class Builder {
 
 		private final LauncherDiscoveryRequestBuilder requestBuilder = LauncherDiscoveryRequestBuilder.request() //
-				.enableImplicitConfigurationParameters(false);
+				.enableImplicitConfigurationParameters(false) //
+				.outputDirectoryCreator(DisabledOutputDirectoryCreator.INSTANCE);
 		private final TestEngine testEngine;
 
 		private Builder(TestEngine testEngine) {
@@ -422,6 +517,69 @@ public final class EngineTestKit {
 			return this;
 		}
 
+		/**
+		 * Set the
+		 * {@link org.junit.platform.engine.reporting.OutputDirectoryProvider}
+		 * to use.
+		 *
+		 * <p>If not specified, a default provider will be used that throws an
+		 * exception when attempting to create output directories. This is done
+		 * to avoid accidentally writing output files to the file system.
+		 *
+		 * @param outputDirectoryProvider the output directory provider to use;
+		 * never {@code null}
+		 * @return this builder for method chaining
+		 * @since 1.12
+		 * @see org.junit.platform.engine.reporting.OutputDirectoryProvider
+		 * @deprecated Please use
+		 * {@link #outputDirectoryCreator(OutputDirectoryCreator)} instead
+		 */
+		@Deprecated
+		@API(status = DEPRECATED, since = "1.14")
+		public Builder outputDirectoryProvider(
+				org.junit.platform.engine.reporting.OutputDirectoryProvider outputDirectoryProvider) {
+			return outputDirectoryCreator(outputDirectoryProvider);
+		}
+
+		/**
+		 * Set the {@link OutputDirectoryCreator} to use.
+		 *
+		 * <p>If not specified, a default implementation will be used that
+		 * throws an exception when attempting to create output directories.
+		 * This is done to avoid accidentally writing output files to the file
+		 * system.
+		 *
+		 * @param outputDirectoryCreator the output directory creator to use;
+		 * never {@code null}
+		 * @return this builder for method chaining
+		 * @since 1.12
+		 * @see OutputDirectoryCreator
+		 */
+		@API(status = MAINTAINED, since = "1.14")
+		public Builder outputDirectoryCreator(OutputDirectoryCreator outputDirectoryCreator) {
+			this.requestBuilder.outputDirectoryCreator(outputDirectoryCreator);
+			return this;
+		}
+
+		/**
+		 * Discover tests for the configured {@link TestEngine},
+		 * {@linkplain DiscoverySelector discovery selectors},
+		 * {@linkplain DiscoveryFilter discovery filters}, and
+		 * <em>configuration parameters</em>.
+		 *
+		 * @return the recorded {@code EngineDiscoveryResults}
+		 * @since 1.13
+		 * @see #selectors(DiscoverySelector...)
+		 * @see #filters(Filter...)
+		 * @see #configurationParameter(String, String)
+		 * @see #configurationParameters(Map)
+		 */
+		@API(status = MAINTAINED, since = "1.13.3")
+		public EngineDiscoveryResults discover() {
+			LauncherDiscoveryRequest request = this.requestBuilder.build();
+			return EngineTestKit.discover(this.testEngine, request);
+		}
+
 		/**
 		 * Execute tests for the configured {@link TestEngine},
 		 * {@linkplain DiscoverySelector discovery selectors},
@@ -441,6 +599,27 @@ public final class EngineTestKit {
 			return executionRecorder.getExecutionResults();
 		}
 
+		private static class DisabledOutputDirectoryCreator implements OutputDirectoryCreator {
+
+			public static final OutputDirectoryCreator INSTANCE = new DisabledOutputDirectoryCreator();
+
+			private static final String FAILURE_MESSAGE = "Writing outputs is disabled by default when using EngineTestKit. "
+					+ "To enable, configure a custom OutputDirectoryCreator via EngineTestKit#outputDirectoryCreator.";
+
+			private DisabledOutputDirectoryCreator() {
+			}
+
+			@Override
+			public Path getRootDirectory() {
+				throw new JUnitException(FAILURE_MESSAGE);
+			}
+
+			@Override
+			public Path createOutputDirectory(TestDescriptor testDescriptor) {
+				throw new JUnitException(FAILURE_MESSAGE);
+			}
+
+		}
 	}
 
 }
