@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -16,6 +16,8 @@ import static org.junit.jupiter.api.Assumptions.assumeTrue;
 import static org.junit.platform.engine.discovery.DiscoverySelectors.selectClass;
 import static org.junit.platform.engine.discovery.DiscoverySelectors.selectMethod;
 import static org.junit.platform.engine.discovery.DiscoverySelectors.selectUniqueId;
+import static org.junit.platform.launcher.core.NamespacedHierarchicalStoreProviders.dummyNamespacedHierarchicalStore;
+import static org.junit.platform.launcher.core.OutputDirectoryCreators.dummyOutputDirectoryCreator;
 import static org.junit.platform.testkit.engine.EventConditions.abortedWithReason;
 import static org.junit.platform.testkit.engine.EventConditions.container;
 import static org.junit.platform.testkit.engine.EventConditions.displayName;
@@ -40,13 +42,13 @@ import junit.runner.Version;
 import org.assertj.core.api.Condition;
 import org.junit.AssumptionViolatedException;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.DisabledInEclipse;
 import org.junit.platform.engine.EngineExecutionListener;
 import org.junit.platform.engine.ExecutionRequest;
 import org.junit.platform.engine.TestDescriptor;
 import org.junit.platform.engine.TestEngine;
 import org.junit.platform.engine.TestExecutionResult;
 import org.junit.platform.engine.UniqueId;
-import org.junit.platform.engine.reporting.ReportEntry;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
 import org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder;
 import org.junit.platform.testkit.engine.EngineExecutionResults;
@@ -182,7 +184,7 @@ class VintageTestEngineExecutionTests {
 		String commonNestedClassPrefix = EnclosedWithParameterizedChildrenJUnit4TestCase.class.getName()
 				+ "$NestedTestCase";
 
-		execute(testClass).allEvents().debug().assertEventsMatchExactly( //
+		execute(testClass).allEvents().assertEventsMatchExactly( //
 			event(engine(), started()), //
 			event(container(testClass), started()), //
 			event(container(commonNestedClassPrefix), started()), //
@@ -397,14 +399,6 @@ class VintageTestEngineExecutionTests {
 				PlainJUnit4TestCaseWithLifecycleMethods.EVENTS.add(
 					"executionSkipped:" + testDescriptor.getDisplayName());
 			}
-
-			@Override
-			public void dynamicTestRegistered(TestDescriptor testDescriptor) {
-			}
-
-			@Override
-			public void reportingEntryPublished(TestDescriptor testDescriptor, ReportEntry entry) {
-			}
 		};
 
 		execute(testClass, listener);
@@ -506,7 +500,7 @@ class VintageTestEngineExecutionTests {
 
 		Class<?> testClass = ParameterizedTimingTestCase.class;
 
-		var events = execute(testClass).allEvents().debug();
+		var events = execute(testClass).allEvents();
 
 		var firstParamStartedEvent = events.filter(event(container("[foo]"), started())::matches).findFirst() //
 				.orElseThrow(() -> new AssertionError("No start event for [foo]"));
@@ -647,7 +641,7 @@ class VintageTestEngineExecutionTests {
 
 		@Override
 		public void run(RunNotifier notifier) {
-			var staticDescription = getDescription().getChildren().get(0);
+			var staticDescription = getDescription().getChildren().getFirst();
 			notifier.fireTestStarted(staticDescription);
 			notifier.fireTestFinished(staticDescription);
 			var dynamicDescription = createTestDescription(testClass, "dynamicTest");
@@ -749,7 +743,7 @@ class VintageTestEngineExecutionTests {
 					instanceOf(MultipleFailuresError.class), //
 					new Condition<>(throwable -> ((MultipleFailuresError) throwable).getFailures().size() == 3,
 						"MultipleFailuresError must contain 3 failures"), //
-					new Condition<>(throwable -> ((MultipleFailuresError) throwable).getSuppressed().length == 3,
+					new Condition<>(throwable -> throwable.getSuppressed().length == 3,
 						"MultipleFailuresError must contain 3 suppressed exceptions")//
 				)), //
 			event(container(testClass), finishedSuccessfully()), //
@@ -869,6 +863,7 @@ class VintageTestEngineExecutionTests {
 	}
 
 	@Test
+	@DisabledInEclipse
 	void executesUnrolledSpockFeatureMethod() {
 		Class<?> testClass = SpockTestCaseWithUnrolledAndRegularFeatureMethods.class;
 		var request = LauncherDiscoveryRequestBuilder.request().selectors(
@@ -887,6 +882,7 @@ class VintageTestEngineExecutionTests {
 	}
 
 	@Test
+	@DisabledInEclipse
 	void executesRegularSpockFeatureMethod() {
 		Class<?> testClass = SpockTestCaseWithUnrolledAndRegularFeatureMethods.class;
 		var request = LauncherDiscoveryRequestBuilder.request().selectors(selectMethod(testClass, "regular")).build();
@@ -933,7 +929,8 @@ class VintageTestEngineExecutionTests {
 		var discoveryRequest = request(testClass);
 		var engineTestDescriptor = testEngine.discover(discoveryRequest, UniqueId.forEngine(testEngine.getId()));
 		testEngine.execute(
-			new ExecutionRequest(engineTestDescriptor, listener, discoveryRequest.getConfigurationParameters()));
+			ExecutionRequest.create(engineTestDescriptor, listener, discoveryRequest.getConfigurationParameters(),
+				dummyOutputDirectoryCreator(), dummyNamespacedHierarchicalStore()));
 	}
 
 	private static LauncherDiscoveryRequest request(Class<?> testClass) {
