@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -18,7 +18,6 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import org.junit.jupiter.api.extension.BeforeEachCallback;
 import org.junit.jupiter.api.extension.ExtensionContext;
-import org.junit.jupiter.api.extension.ExtensionContext.Store.CloseableResource;
 import org.junit.jupiter.api.extension.ParameterContext;
 import org.junit.jupiter.api.extension.ParameterResolver;
 
@@ -52,12 +51,12 @@ public class Heavyweight implements ParameterResolver, BeforeEachCallback {
 	/**
 	 * Demo resource class.
 	 *
-	 * <p>The class implements interface {@link CloseableResource}
+	 * <p>The class implements interface {@link AutoCloseable}
 	 * and interface {@link AutoCloseable} to show and ensure that a single
 	 * {@link ResourceValue#close()} method implementation is needed to comply
 	 * with both interfaces.
 	 */
-	static class ResourceValue implements Resource, CloseableResource, AutoCloseable {
+	static class ResourceValue implements Resource, AutoCloseable {
 
 		static final AtomicInteger creations = new AtomicInteger();
 		private final AtomicInteger usages = new AtomicInteger();
@@ -80,7 +79,7 @@ public class Heavyweight implements ParameterResolver, BeforeEachCallback {
 		}
 	}
 
-	private static class CloseableOnlyOnceResource implements CloseableResource {
+	private static class CloseableOnlyOnceResource implements AutoCloseable {
 
 		private final AtomicBoolean closed = new AtomicBoolean();
 
