@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -11,7 +11,7 @@
 package org.junit.platform.commons.support;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.platform.commons.support.PreconditionAssertions.assertPreconditionViolationException;
+import static org.junit.platform.commons.test.PreconditionAssertions.assertPreconditionViolationNotNullFor;
 
 import java.util.List;
 import java.util.function.Function;
@@ -27,7 +27,7 @@ class ClassSupportTests {
 	@Test
 	void nullSafeToStringPreconditions() {
 		Function<? super Class<?>, ? extends String> mapper = null;
-		assertPreconditionViolationException("Mapping function",
+		assertPreconditionViolationNotNullFor("Mapping function",
 			() -> ClassSupport.nullSafeToString(mapper, String.class, List.class));
 	}
 
@@ -40,4 +40,5 @@ class ClassSupportTests {
 		assertEquals(ClassUtils.nullSafeToString(classToStringMapper, String.class, List.class),
 			ClassSupport.nullSafeToString(classToStringMapper, String.class, List.class));
 	}
+
 }
