@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -14,11 +14,15 @@ import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.platform.commons.support.PreconditionAssertions.assertPreconditionViolationException;
-import static org.junit.platform.commons.support.PreconditionAssertions.assertPreconditionViolationExceptionForString;
+import static org.junit.platform.commons.support.ReflectionSupport.toSupportResourcesList;
+import static org.junit.platform.commons.support.ReflectionSupport.toSupportResourcesStream;
+import static org.junit.platform.commons.test.PreconditionAssertions.assertPreconditionViolationNotNullFor;
+import static org.junit.platform.commons.test.PreconditionAssertions.assertPreconditionViolationNotNullOrBlankFor;
+import static org.junit.platform.commons.util.ClassLoaderUtils.getDefaultClassLoader;
 
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
+import java.net.URI;
 import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.List;
@@ -28,6 +32,7 @@ import org.junit.jupiter.api.DynamicTest;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.TestFactory;
 import org.junit.platform.commons.PreconditionViolationException;
+import org.junit.platform.commons.io.ResourceFilter;
 import org.junit.platform.commons.util.ReflectionUtils;
 
 /**
@@ -36,6 +41,8 @@ import org.junit.platform.commons.util.ReflectionUtils;
 class ReflectionSupportTests {
 
 	private static final Predicate<Class<?>> allTypes = type -> true;
+	@SuppressWarnings("deprecation")
+	private static final Predicate<Resource> allResources = __ -> true;
 	private static final Predicate<String> allNames = name -> true;
 	private static final Predicate<Method> allMethods = name -> true;
 	private static final Predicate<Field> allFields = name -> true;
@@ -54,8 +61,8 @@ class ReflectionSupportTests {
 	@Test
 	@SuppressWarnings("deprecation")
 	void loadClassPreconditions() {
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.loadClass(null));
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.loadClass(""));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.loadClass(null));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.loadClass(""));
 	}
 
 	@Test
@@ -70,8 +77,8 @@ class ReflectionSupportTests {
 
 	@Test
 	void tryToLoadClassPreconditions() {
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.tryToLoadClass(null));
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.tryToLoadClass(""));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.tryToLoadClass(null));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.tryToLoadClass(""));
 	}
 
 	/**
@@ -94,12 +101,12 @@ class ReflectionSupportTests {
 	 */
 	@Test
 	void tryToLoadClassWithExplicitClassLoaderPreconditions() {
-		ClassLoader cl = getClass().getClassLoader();
+		var cl = getClass().getClassLoader();
 
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.tryToLoadClass(null, cl));
-		assertPreconditionViolationExceptionForString("Class name", () -> ReflectionSupport.tryToLoadClass("", cl));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.tryToLoadClass(null, cl));
+		assertPreconditionViolationNotNullOrBlankFor("Class name", () -> ReflectionSupport.tryToLoadClass("", cl));
 
-		assertPreconditionViolationException("ClassLoader", () -> ReflectionSupport.tryToLoadClass("int", null));
+		assertPreconditionViolationNotNullFor("ClassLoader", () -> ReflectionSupport.tryToLoadClass("int", null));
 	}
 
 	@TestFactory
@@ -110,28 +117,120 @@ class ReflectionSupportTests {
 		paths.addAll(ReflectionUtils.getAllClasspathRootDirectories());
 		for (var path : paths) {
 			var root = path.toUri();
-			var displayName = root.getPath();
-			if (displayName.length() > 42) {
-				displayName = "..." + displayName.substring(displayName.length() - 42);
-			}
-			tests.add(DynamicTest.dynamicTest(displayName,
+			tests.add(DynamicTest.dynamicTest(createDisplayName(root),
 				() -> assertEquals(ReflectionUtils.findAllClassesInClasspathRoot(root, allTypes, allNames),
 					ReflectionSupport.findAllClassesInClasspathRoot(root, allTypes, allNames))));
 		}
 		return tests;
 	}
 
+	/**
+	 * @since 1.12
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void tryToGetResourcesPreconditions() {
+		assertPreconditionViolationNotNullOrBlankFor("Resource name", () -> ReflectionSupport.tryToGetResources(null));
+		assertPreconditionViolationNotNullOrBlankFor("Resource name", () -> ReflectionSupport.tryToGetResources(""));
+		assertPreconditionViolationNotNullFor("Class loader",
+			() -> ReflectionSupport.tryToGetResources("default-package.resource", null));
+		assertPreconditionViolationNotNullFor("Class loader",
+			() -> ReflectionSupport.tryToGetResources("default-package.resource", null));
+	}
+
+	/**
+	 * @since 1.12
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void tryToGetResources() {
+		assertEquals(
+			ReflectionUtils.tryToGetResources("default-package.resource").toOptional().map(
+				ReflectionSupport::toSupportResourcesSet),
+			ReflectionSupport.tryToGetResources("default-package.resource").toOptional());
+		assertEquals(
+			ReflectionUtils.tryToGetResources("default-package.resource", getDefaultClassLoader()).toOptional().map(
+				ReflectionSupport::toSupportResourcesSet), //
+			ReflectionSupport.tryToGetResources("default-package.resource", getDefaultClassLoader()).toOptional());
+	}
+
 	@Test
 	void findAllClassesInClasspathRootPreconditions() {
 		var path = Path.of(".").toUri();
-		assertPreconditionViolationException("root",
+		assertPreconditionViolationNotNullFor("root",
 			() -> ReflectionSupport.findAllClassesInClasspathRoot(null, allTypes, allNames));
-		assertPreconditionViolationException("class predicate",
+		assertPreconditionViolationNotNullFor("class predicate",
 			() -> ReflectionSupport.findAllClassesInClasspathRoot(path, null, allNames));
-		assertPreconditionViolationException("name predicate",
+		assertPreconditionViolationNotNullFor("name predicate",
 			() -> ReflectionSupport.findAllClassesInClasspathRoot(path, allTypes, null));
 	}
 
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@TestFactory
+	List<DynamicTest> findAllResourcesInClasspathRootDelegates() throws Throwable {
+		List<DynamicTest> tests = new ArrayList<>();
+		List<Path> paths = new ArrayList<>();
+		paths.add(Path.of(".").toRealPath());
+		paths.addAll(ReflectionUtils.getAllClasspathRootDirectories());
+		for (var path : paths) {
+			var root = path.toUri();
+			tests.add(DynamicTest.dynamicTest(createDisplayName(root), () -> assertThat(toSupportResourcesList(
+				ReflectionUtils.findAllResourcesInClasspathRoot(root, ResourceFilter.of(__ -> true)))) //
+						.containsExactlyElementsOf(
+							ReflectionSupport.findAllResourcesInClasspathRoot(root, allResources))));
+		}
+		return tests;
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void findAllResourcesInClasspathRootPreconditions() {
+		var path = Path.of(".").toUri();
+		assertPreconditionViolationNotNullFor("root",
+			() -> ReflectionSupport.findAllResourcesInClasspathRoot(null, allResources));
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.findAllResourcesInClasspathRoot(path, null));
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@TestFactory
+	List<DynamicTest> streamAllResourcesInClasspathRootDelegates() throws Throwable {
+		List<DynamicTest> tests = new ArrayList<>();
+		List<Path> paths = new ArrayList<>();
+		paths.add(Path.of(".").toRealPath());
+		paths.addAll(ReflectionUtils.getAllClasspathRootDirectories());
+		for (var path : paths) {
+			var root = path.toUri();
+			tests.add(DynamicTest.dynamicTest(createDisplayName(root), () -> assertThat(toSupportResourcesStream(
+				ReflectionUtils.streamAllResourcesInClasspathRoot(root, ResourceFilter.of(__ -> true)))) //
+						.containsExactlyElementsOf(
+							ReflectionSupport.streamAllResourcesInClasspathRoot(root, allResources).toList())));
+		}
+		return tests;
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void streamAllResourcesInClasspathRootPreconditions() {
+		var path = Path.of(".").toUri();
+		assertPreconditionViolationNotNullFor("root",
+			() -> ReflectionSupport.streamAllResourcesInClasspathRoot(null, allResources));
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.streamAllResourcesInClasspathRoot(path, null));
+	}
+
 	@Test
 	void findAllClassesInPackageDelegates() {
 		assertNotEquals(0, ReflectionSupport.findAllClassesInPackage("org.junit", allTypes, allNames).size());
@@ -141,14 +240,66 @@ class ReflectionSupportTests {
 
 	@Test
 	void findAllClassesInPackagePreconditions() {
-		assertPreconditionViolationExceptionForString("basePackageName",
+		assertPreconditionViolationNotNullOrBlankFor("basePackageName",
 			() -> ReflectionSupport.findAllClassesInPackage(null, allTypes, allNames));
-		assertPreconditionViolationException("class predicate",
+		assertPreconditionViolationNotNullFor("class predicate",
 			() -> ReflectionSupport.findAllClassesInPackage("org.junit", null, allNames));
-		assertPreconditionViolationException("name predicate",
+		assertPreconditionViolationNotNullFor("name predicate",
 			() -> ReflectionSupport.findAllClassesInPackage("org.junit", allTypes, null));
 	}
 
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void findAllResourcesInPackageDelegates() {
+		assertNotEquals(0, ReflectionSupport.findAllResourcesInPackage("org.junit", allResources).size());
+
+		assertEquals(
+			toSupportResourcesList(
+				ReflectionUtils.findAllResourcesInPackage("org.junit", ResourceFilter.of(__ -> true))),
+			ReflectionSupport.findAllResourcesInPackage("org.junit", allResources));
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void findAllResourcesInPackagePreconditions() {
+		assertPreconditionViolationNotNullOrBlankFor("basePackageName",
+			() -> ReflectionSupport.findAllResourcesInPackage(null, allResources));
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.findAllResourcesInPackage("org.junit", null));
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void streamAllResourcesInPackageDelegates() {
+		assertNotEquals(0, ReflectionSupport.streamAllResourcesInPackage("org.junit", allResources).count());
+
+		assertEquals(
+			toSupportResourcesStream(
+				ReflectionUtils.streamAllResourcesInPackage("org.junit", ResourceFilter.of(__ -> true))).toList(),
+			ReflectionSupport.streamAllResourcesInPackage("org.junit", allResources).toList());
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void streamAllResourcesInPackagePreconditions() {
+		assertPreconditionViolationNotNullOrBlankFor("basePackageName",
+			() -> ReflectionSupport.streamAllResourcesInPackage(null, allResources));
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.streamAllResourcesInPackage("org.junit", null));
+	}
+
 	@Test
 	void findAllClassesInModuleDelegates() {
 		assertEquals(ReflectionUtils.findAllClassesInModule("org.junit.platform.commons", allTypes, allNames),
@@ -160,12 +311,61 @@ class ReflectionSupportTests {
 		var exception = assertThrows(PreconditionViolationException.class,
 			() -> ReflectionSupport.findAllClassesInModule(null, allTypes, allNames));
 		assertEquals("Module name must not be null or empty", exception.getMessage());
-		assertPreconditionViolationException("class predicate",
+		assertPreconditionViolationNotNullFor("class predicate",
 			() -> ReflectionSupport.findAllClassesInModule("org.junit.platform.commons", null, allNames));
-		assertPreconditionViolationException("name predicate",
+		assertPreconditionViolationNotNullFor("name predicate",
 			() -> ReflectionSupport.findAllClassesInModule("org.junit.platform.commons", allTypes, null));
 	}
 
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void findAllResourcesInModuleDelegates() {
+		assertEquals(
+			ReflectionUtils.findAllResourcesInModule("org.junit.platform.commons", ResourceFilter.of(__ -> true)),
+			ReflectionSupport.findAllResourcesInModule("org.junit.platform.commons", allResources));
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void findAllResourcesInModulePreconditions() {
+		var exception = assertThrows(PreconditionViolationException.class,
+			() -> ReflectionSupport.findAllResourcesInModule(null, allResources));
+		assertEquals("Module name must not be null or empty", exception.getMessage());
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.findAllResourcesInModule("org.junit.platform.commons", null));
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void streamAllResourcesInModuleDelegates() {
+		assertEquals(
+			toSupportResourcesStream(ReflectionUtils.streamAllResourcesInModule("org.junit.platform.commons",
+				ResourceFilter.of(__ -> true))).toList(),
+			ReflectionSupport.streamAllResourcesInModule("org.junit.platform.commons", allResources).toList());
+	}
+
+	/**
+	 * @since 1.11
+	 */
+	@SuppressWarnings("deprecation")
+	@Test
+	void streamAllResourcesInModulePreconditions() {
+		var exception = assertThrows(PreconditionViolationException.class,
+			() -> ReflectionSupport.streamAllResourcesInModule(null, allResources));
+		assertEquals("Module name must not be null or empty", exception.getMessage());
+		assertPreconditionViolationNotNullFor("resourceFilter",
+			() -> ReflectionSupport.streamAllResourcesInModule("org.junit.platform.commons", null));
+	}
+
 	@Test
 	void newInstanceDelegates() {
 		assertEquals(ReflectionUtils.newInstance(String.class, "foo"),
@@ -174,10 +374,10 @@ class ReflectionSupportTests {
 
 	@Test
 	void newInstancePreconditions() {
-		assertPreconditionViolationException("Class", () -> ReflectionSupport.newInstance(null));
-		assertPreconditionViolationException("Argument array",
+		assertPreconditionViolationNotNullFor("Class", () -> ReflectionSupport.newInstance(null));
+		assertPreconditionViolationNotNullFor("Argument array",
 			() -> ReflectionSupport.newInstance(String.class, (Object[]) null));
-		assertPreconditionViolationException("Individual arguments",
+		assertPreconditionViolationNotNullFor("Individual arguments",
 			() -> ReflectionSupport.newInstance(String.class, new Object[] { null }));
 	}
 
@@ -190,7 +390,7 @@ class ReflectionSupportTests {
 
 	@Test
 	void invokeMethodPreconditions() throws Exception {
-		assertPreconditionViolationException("Method", () -> ReflectionSupport.invokeMethod(null, null, "true"));
+		assertPreconditionViolationNotNullFor("Method", () -> ReflectionSupport.invokeMethod(null, null, "true"));
 
 		var method = Boolean.class.getMethod("toString");
 		var exception = assertThrows(PreconditionViolationException.class,
@@ -213,15 +413,15 @@ class ReflectionSupportTests {
 
 	@Test
 	void findFieldsPreconditions() {
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findFields(null, allFields, HierarchyTraversalMode.BOTTOM_UP));
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findFields(null, allFields, HierarchyTraversalMode.TOP_DOWN));
-		assertPreconditionViolationException("Predicate",
+		assertPreconditionViolationNotNullFor("Predicate",
 			() -> ReflectionSupport.findFields(ReflectionSupportTests.class, null, HierarchyTraversalMode.BOTTOM_UP));
-		assertPreconditionViolationException("Predicate",
+		assertPreconditionViolationNotNullFor("Predicate",
 			() -> ReflectionSupport.findFields(ReflectionSupportTests.class, null, HierarchyTraversalMode.TOP_DOWN));
-		assertPreconditionViolationException("HierarchyTraversalMode",
+		assertPreconditionViolationNotNullFor("HierarchyTraversalMode",
 			() -> ReflectionSupport.findFields(ReflectionSupportTests.class, allFields, null));
 	}
 
@@ -238,7 +438,7 @@ class ReflectionSupportTests {
 
 	@Test
 	void tryToReadFieldValuePreconditions() throws Exception {
-		assertPreconditionViolationException("Field", () -> ReflectionSupport.tryToReadFieldValue(null, this));
+		assertPreconditionViolationNotNullFor("Field", () -> ReflectionSupport.tryToReadFieldValue(null, this));
 
 		var instanceField = getClass().getDeclaredField("instanceField");
 		Exception exception = assertThrows(PreconditionViolationException.class,
@@ -259,22 +459,22 @@ class ReflectionSupportTests {
 
 	@Test
 	void findMethodPreconditions() {
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findMethod(null, "valueOf", String.class.getName()));
-		assertPreconditionViolationExceptionForString("Method name",
+		assertPreconditionViolationNotNullOrBlankFor("Method name",
 			() -> ReflectionSupport.findMethod(Boolean.class, "", String.class.getName()));
-		assertPreconditionViolationExceptionForString("Method name",
+		assertPreconditionViolationNotNullOrBlankFor("Method name",
 			() -> ReflectionSupport.findMethod(Boolean.class, "   ", String.class.getName()));
 
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findMethod(null, "valueOf", String.class));
-		assertPreconditionViolationExceptionForString("Method name",
+		assertPreconditionViolationNotNullOrBlankFor("Method name",
 			() -> ReflectionSupport.findMethod(Boolean.class, "", String.class));
-		assertPreconditionViolationExceptionForString("Method name",
+		assertPreconditionViolationNotNullOrBlankFor("Method name",
 			() -> ReflectionSupport.findMethod(Boolean.class, "   ", String.class));
-		assertPreconditionViolationException("Parameter types array",
+		assertPreconditionViolationNotNullFor("Parameter types array",
 			() -> ReflectionSupport.findMethod(Boolean.class, "valueOf", (Class<?>[]) null));
-		assertPreconditionViolationException("Individual parameter types",
+		assertPreconditionViolationNotNullFor("Individual parameter types",
 			() -> ReflectionSupport.findMethod(Boolean.class, "valueOf", new Class<?>[] { null }));
 	}
 
@@ -292,15 +492,15 @@ class ReflectionSupportTests {
 
 	@Test
 	void findMethodsPreconditions() {
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findMethods(null, allMethods, HierarchyTraversalMode.BOTTOM_UP));
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findMethods(null, allMethods, HierarchyTraversalMode.TOP_DOWN));
-		assertPreconditionViolationException("Predicate",
+		assertPreconditionViolationNotNullFor("Predicate",
 			() -> ReflectionSupport.findMethods(ReflectionSupportTests.class, null, HierarchyTraversalMode.BOTTOM_UP));
-		assertPreconditionViolationException("Predicate",
+		assertPreconditionViolationNotNullFor("Predicate",
 			() -> ReflectionSupport.findMethods(ReflectionSupportTests.class, null, HierarchyTraversalMode.TOP_DOWN));
-		assertPreconditionViolationException("HierarchyTraversalMode",
+		assertPreconditionViolationNotNullFor("HierarchyTraversalMode",
 			() -> ReflectionSupport.findMethods(ReflectionSupportTests.class, allMethods, null));
 	}
 
@@ -312,17 +512,27 @@ class ReflectionSupportTests {
 
 	@Test
 	void findNestedClassesPreconditions() {
-		assertPreconditionViolationException("Class",
+		assertPreconditionViolationNotNullFor("Class",
 			() -> ReflectionSupport.findNestedClasses(null, ReflectionUtils::isStatic));
-		assertPreconditionViolationException("Predicate",
+		assertPreconditionViolationNotNullFor("Predicate",
 			() -> ReflectionSupport.findNestedClasses(ClassWithNestedClasses.class, null));
 	}
 
+	private static String createDisplayName(URI root) {
+		var displayName = root.getPath();
+		if (displayName.length() > 42) {
+			displayName = "..." + displayName.substring(displayName.length() - 42);
+		}
+		return displayName;
+	}
+
 	static class ClassWithNestedClasses {
 
+		@SuppressWarnings({ "InnerClassMayBeStatic", "unused" })
 		class Nested1 {
 		}
 
+		@SuppressWarnings("unused")
 		static class Nested2 {
 		}
 
