@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -11,11 +11,11 @@
 package org.junit.platform.commons.util;
 
 import static org.assertj.core.api.Assertions.assertThat;
-import static org.assertj.core.api.Assertions.assertThatExceptionOfType;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.platform.commons.test.PreconditionAssertions.assertPreconditionViolationFor;
 import static org.mockito.Mockito.mock;
 
 import org.junit.jupiter.api.Test;
@@ -31,8 +31,7 @@ class ClassLoaderUtilsTests {
 
 	@Test
 	void getClassLoaderPreconditions() {
-		assertThatExceptionOfType(PreconditionViolationException.class)//
-				.isThrownBy(() -> ClassLoaderUtils.getClassLoader(null))//
+		assertPreconditionViolationFor(() -> ClassLoaderUtils.getClassLoader(null))//
 				.withMessage("Class must not be null");
 	}
 
@@ -108,8 +107,7 @@ class ClassLoaderUtilsTests {
 
 	@Test
 	void getLocationFromVariousObjectsArePresent() {
-		assertTrue(ClassLoaderUtils.getLocation(void.class).isPresent());
-		assertTrue(ClassLoaderUtils.getLocation(byte.class).isPresent());
+		assertTrue(ClassLoaderUtils.getLocation(getClass()).isPresent());
 		assertTrue(ClassLoaderUtils.getLocation(this).isPresent());
 		assertTrue(ClassLoaderUtils.getLocation("").isPresent());
 		assertTrue(ClassLoaderUtils.getLocation(0).isPresent());
