@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -20,8 +20,8 @@ import java.util.stream.Stream;
 
 import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.Arguments;
+import org.junit.jupiter.params.provider.EmptySource;
 import org.junit.jupiter.params.provider.MethodSource;
-import org.junit.platform.console.tasks.ConsoleTestExecutor;
 
 /**
  * @since 1.0
@@ -31,50 +31,60 @@ class ConsoleLauncherTests {
 	private final StringWriter stringWriter = new StringWriter();
 	private final PrintWriter printSink = new PrintWriter(stringWriter);
 
-	@ParameterizedTest(name = "{0}")
+	@ParameterizedTest(name = "cmd={0}")
+	@EmptySource
 	@MethodSource("commandsWithEmptyOptionExitCodes")
 	void displayHelp(String command) {
-		var consoleLauncher = new ConsoleLauncher(ConsoleTestExecutor::new, printSink, printSink);
-		var exitCode = consoleLauncher.run(command, "--help").getExitCode();
+		var exitCode = ConsoleLauncher.run(printSink, printSink, command, "--help").getExitCode();
 
 		assertEquals(0, exitCode);
-		assertThat(stringWriter.toString()).contains("--help", "--disable-banner" /* ... */);
+		assertThat(output()).contains("--help");
+	}
+
+	@ParameterizedTest(name = "cmd={0}")
+	@EmptySource
+	@MethodSource("commandsWithEmptyOptionExitCodes")
+	void displayVersion(String command) {
+		var exitCode = ConsoleLauncher.run(printSink, printSink, command, "--version").getExitCode();
+
+		assertEquals(0, exitCode);
+		assertThat(output()).contains("JUnit Platform Console Launcher");
 	}
 
 	@ParameterizedTest(name = "{0}")
 	@MethodSource("commandsWithEmptyOptionExitCodes")
 	void displayBanner(String command) {
-		var consoleLauncher = new ConsoleLauncher(ConsoleTestExecutor::new, printSink, printSink);
-		consoleLauncher.run(command);
+		ConsoleLauncher.run(printSink, printSink, command);
 
-		assertThat(stringWriter.toString()).contains("Thanks for using JUnit!");
+		assertThat(output()).contains("Thanks for using JUnit!");
 	}
 
 	@ParameterizedTest(name = "{0}")
 	@MethodSource("commandsWithEmptyOptionExitCodes")
 	void disableBanner(String command, int expectedExitCode) {
-		var consoleLauncher = new ConsoleLauncher(ConsoleTestExecutor::new, printSink, printSink);
-		var exitCode = consoleLauncher.run(command, "--disable-banner").getExitCode();
+		var exitCode = ConsoleLauncher.run(printSink, printSink, command, "--disable-banner").getExitCode();
 
 		assertEquals(expectedExitCode, exitCode);
-		assertThat(stringWriter.toString()).doesNotContain("Thanks for using JUnit!");
+		assertThat(output()).doesNotContain("Thanks for using JUnit!");
 	}
 
 	@ParameterizedTest(name = "{0}")
 	@MethodSource("commandsWithEmptyOptionExitCodes")
 	void executeWithUnknownCommandLineOption(String command) {
-		var consoleLauncher = new ConsoleLauncher(ConsoleTestExecutor::new, printSink, printSink);
-		var exitCode = consoleLauncher.run(command, "--all").getExitCode();
+		var exitCode = ConsoleLauncher.run(printSink, printSink, command, "--all").getExitCode();
 
 		assertEquals(-1, exitCode);
-		assertThat(stringWriter.toString()).contains("Unknown option: '--all'").contains("Usage:");
+		assertThat(output()).contains("Unknown option: '--all'").contains("Usage:");
+	}
+
+	private String output() {
+		return stringWriter.toString();
 	}
 
 	@ParameterizedTest(name = "{0}")
 	@MethodSource("commandsWithEmptyOptionExitCodes")
 	void executeWithoutCommandLineOptions(String command, int expectedExitCode) {
-		var consoleLauncher = new ConsoleLauncher(ConsoleTestExecutor::new, printSink, printSink);
-		var actualExitCode = consoleLauncher.run(command).getExitCode();
+		var actualExitCode = ConsoleLauncher.run(printSink, printSink, command).getExitCode();
 
 		assertEquals(expectedExitCode, actualExitCode);
 	}
