@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -12,6 +12,7 @@ package org.junit.platform.launcher.core;
 
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
+import static org.junit.platform.launcher.core.OutputDirectoryCreators.dummyOutputDirectoryCreator;
 import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.mock;
 
@@ -206,13 +207,13 @@ class CompositeTestExecutionListenerTests {
 	}
 
 	private static TestPlan anyTestPlan() {
-		return TestPlan.from(Set.of(anyTestDescriptor()), mock());
+		return TestPlan.from(true, Set.of(anyTestDescriptor()), mock(), dummyOutputDirectoryCreator());
 	}
 
 	private static DemoMethodTestDescriptor anyTestDescriptor() {
 		var testClass = CompositeTestExecutionListenerTests.class;
 		var method = ReflectionUtils.findMethod(testClass, "anyTestDescriptor", new Class<?>[0]).orElseThrow();
-		return new DemoMethodTestDescriptor(UniqueId.root("method", "unique_id"), testClass, method);
+		return new DemoMethodTestDescriptor(UniqueId.root("method", "unique_id"), method);
 	}
 
 	private static class ThrowingEagerTestExecutionListener extends ThrowingTestExecutionListener
