@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -10,36 +10,41 @@
 
 package org.junit.platform.launcher.core;
 
-import static java.util.stream.Collectors.toList;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.TemporaryClasspathExecutor.withAdditionalClasspathRoot;
 import static org.junit.platform.engine.discovery.DiscoverySelectors.selectClass;
 import static org.junit.platform.launcher.LauncherConstants.DEACTIVATE_LISTENERS_PATTERN_PROPERTY_NAME;
 import static org.junit.platform.launcher.LauncherConstants.ENABLE_LAUNCHER_INTERCEPTORS;
 import static org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder.request;
 
-import java.io.IOException;
-import java.io.UncheckedIOException;
-import java.net.URL;
-import java.net.URLClassLoader;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.logging.LogRecord;
 
 import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.BeforeAllCallback;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.extension.ExtensionContext;
+import org.junit.jupiter.api.extension.ExtensionContext.StoreScope;
+import org.junit.jupiter.api.fixtures.TrackLogRecords;
 import org.junit.jupiter.engine.JupiterTestEngine;
 import org.junit.platform.commons.PreconditionViolationException;
+import org.junit.platform.commons.logging.LogRecordListener;
 import org.junit.platform.engine.EngineDiscoveryRequest;
 import org.junit.platform.engine.ExecutionRequest;
 import org.junit.platform.engine.TestDescriptor;
 import org.junit.platform.engine.TestExecutionResult;
 import org.junit.platform.engine.UniqueId;
+import org.junit.platform.engine.support.store.Namespace;
 import org.junit.platform.fakes.TestEngineSpy;
 import org.junit.platform.launcher.InterceptedTestEngine;
 import org.junit.platform.launcher.InterceptorInjectedLauncherSessionListener;
 import org.junit.platform.launcher.LauncherConstants;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
+import org.junit.platform.launcher.LauncherSession;
 import org.junit.platform.launcher.LauncherSessionListener;
 import org.junit.platform.launcher.TagFilter;
 import org.junit.platform.launcher.TestExecutionListener;
@@ -80,7 +85,8 @@ class LauncherFactoryTests {
 	}
 
 	@Test
-	void testExecutionListenersExcludedViaConfigParametersIsNotLoadedViaServiceApi() {
+	void testExecutionListenersExcludedViaConfigParametersIsNotLoadedViaServiceApi(
+			@TrackLogRecords LogRecordListener listener) {
 		withTestServices(() -> {
 			var value = "org.junit.*.launcher.listeners.Unused*,org.junit.*.launcher.listeners.AnotherUnused*";
 			withSystemProperty(DEACTIVATE_LISTENERS_PATTERN_PROPERTY_NAME, value, () -> {
@@ -95,6 +101,16 @@ class LauncherFactoryTests {
 
 				launcher.execute(request().build());
 
+				var logMessage = listener.stream(ServiceLoaderRegistry.class) //
+						.map(LogRecord::getMessage) //
+						.filter(it -> it.startsWith("Loaded TestExecutionListener instances")) //
+						.findAny();
+				assertThat(logMessage).isPresent();
+				assertThat(logMessage.get()) //
+						.contains("NoopTestExecutionListener@") //
+						.endsWith(" (excluded classes: [" + UnusedTestExecutionListener.class.getName() + ", "
+								+ AnotherUnusedTestExecutionListener.class.getName() + "])");
+
 				assertFalse(UnusedTestExecutionListener.called);
 				assertFalse(AnotherUnusedTestExecutionListener.called);
 			});
@@ -112,7 +128,7 @@ class LauncherFactoryTests {
 		// @formatter:off
 		var ids = roots.stream()
 				.map(TestIdentifier::getUniqueId)
-				.collect(toList());
+				.toList();
 		// @formatter:on
 
 		assertThat(ids).containsOnly("[engine:junit-vintage]", "[engine:junit-jupiter]",
@@ -135,7 +151,7 @@ class LauncherFactoryTests {
 		// @formatter:off
 		var ids = roots.stream()
 				.map(TestIdentifier::getUniqueId)
-				.collect(toList());
+				.toList();
 		// @formatter:on
 
 		assertThat(ids).containsOnly("[engine:junit-jupiter]");
@@ -320,6 +336,83 @@ class LauncherFactoryTests {
 		}));
 	}
 
+	@Test
+	void extensionCanReadValueFromSessionStoreAndReadByLauncherSessionListenerOnOpened() {
+		var config = LauncherConfig.builder() //
+				.addLauncherSessionListeners(new LauncherSessionListenerOpenedExample()) //
+				.build();
+
+		try (LauncherSession session = LauncherFactory.openSession(config)) {
+			var launcher = session.getLauncher();
+			var request = request().selectors(selectClass(SessionTrackingTestCase.class)).build();
+
+			AtomicReference<Throwable> errorRef = new AtomicReference<>();
+			launcher.execute(request, new TestExecutionListener() {
+				@Override
+				public void executionFinished(TestIdentifier testIdentifier, TestExecutionResult testExecutionResult) {
+					testExecutionResult.getThrowable().ifPresent(errorRef::set);
+				}
+			});
+
+			assertThat(errorRef.get()).isNull();
+		}
+	}
+
+	@Test
+	void extensionCanReadValueFromSessionStoreAndReadByLauncherSessionListenerOnClose() {
+		var config = LauncherConfig.builder() //
+				.addLauncherSessionListeners(new LauncherSessionListenerClosedExample()) //
+				.build();
+
+		try (LauncherSession session = LauncherFactory.openSession(config)) {
+			var launcher = session.getLauncher();
+			var request = request().selectors(selectClass(SessionStoringTestCase.class)).build();
+
+			AtomicReference<Throwable> errorRef = new AtomicReference<>();
+			launcher.execute(request, new TestExecutionListener() {
+				@Override
+				public void executionFinished(TestIdentifier testIdentifier, TestExecutionResult testExecutionResult) {
+					testExecutionResult.getThrowable().ifPresent(errorRef::set);
+				}
+			});
+
+			assertThat(errorRef.get()).isNull();
+		}
+	}
+
+	@Test
+	void sessionResourceClosedOnSessionClose() {
+		CloseTrackingResource.closed = false;
+		var config = LauncherConfig.builder() //
+				.addLauncherSessionListeners(new AutoCloseCheckListener()) //
+				.build();
+
+		try (LauncherSession session = LauncherFactory.openSession(config)) {
+			var launcher = session.getLauncher();
+			var request = request().selectors(selectClass(SessionResourceAutoCloseTestCase.class)).build();
+
+			launcher.execute(request);
+			assertThat(CloseTrackingResource.closed).isFalse();
+		}
+
+		assertThat(CloseTrackingResource.closed).isTrue();
+	}
+
+	@Test
+	void requestResourceClosedOnExecutionClose() {
+		CloseTrackingResource.closed = false;
+		var config = LauncherConfig.builder().build();
+
+		try (LauncherSession session = LauncherFactory.openSession(config)) {
+			var launcher = session.getLauncher();
+			var request = request().selectors(selectClass(RequestResourceAutoCloseTestCase.class)).build();
+
+			launcher.execute(request);
+
+			assertThat(CloseTrackingResource.closed).isTrue();
+		}
+	}
+
 	@SuppressWarnings("SameParameterValue")
 	private static void withSystemProperty(String key, String value, Runnable runnable) {
 		var oldValue = System.getProperty(key);
@@ -338,18 +431,7 @@ class LauncherFactoryTests {
 	}
 
 	private static void withTestServices(Runnable runnable) {
-		var current = Thread.currentThread().getContextClassLoader();
-		var url = LauncherFactoryTests.class.getClassLoader().getResource("testservices/");
-		try (var classLoader = new URLClassLoader(new URL[] { url }, current)) {
-			Thread.currentThread().setContextClassLoader(classLoader);
-			runnable.run();
-		}
-		catch (IOException e) {
-			throw new UncheckedIOException(e);
-		}
-		finally {
-			Thread.currentThread().setContextClassLoader(current);
-		}
+		withAdditionalClasspathRoot("testservices/", runnable);
 	}
 
 	private LauncherDiscoveryRequest createLauncherDiscoveryRequestForBothStandardEngineExampleClasses() {
@@ -361,7 +443,7 @@ class LauncherFactoryTests {
 		// @formatter:on
 	}
 
-	@SuppressWarnings("NewClassNamingConvention")
+	@SuppressWarnings({ "NewClassNamingConvention", "JUnitMalformedDeclaration" })
 	public static class JUnit4Example {
 
 		@org.junit.Test
@@ -370,13 +452,132 @@ class LauncherFactoryTests {
 
 	}
 
-	@SuppressWarnings("NewClassNamingConvention")
+	@SuppressWarnings({ "NewClassNamingConvention", "JUnitMalformedDeclaration" })
 	static class JUnit5Example {
 
 		@Tag("test-post-discovery")
 		@Test
 		void testJ5() {
 		}
+	}
 
+	@SuppressWarnings("JUnitMalformedDeclaration")
+	@ExtendWith(SessionTrackingExtension.class)
+	static class SessionTrackingTestCase {
+
+		@Test
+		void dummyTest() {
+			// Just a placeholder to trigger the extension
+		}
+	}
+
+	@SuppressWarnings("JUnitMalformedDeclaration")
+	@ExtendWith(SessionStoringExtension.class)
+	static class SessionStoringTestCase {
+
+		@Test
+		void dummyTest() {
+			// Just a placeholder to trigger the extension
+		}
+	}
+
+	static class LauncherSessionListenerOpenedExample implements LauncherSessionListener {
+		@Override
+		public void launcherSessionOpened(LauncherSession session) {
+			session.getStore().put(Namespace.GLOBAL, "testKey", "testValue");
+		}
+	}
+
+	static class LauncherSessionListenerClosedExample implements LauncherSessionListener {
+		@Override
+		public void launcherSessionClosed(LauncherSession session) {
+			Object storedValue = session.getStore().get(Namespace.GLOBAL, "testKey");
+			assertThat(storedValue).isEqualTo("testValue");
+		}
+	}
+
+	static class SessionTrackingExtension implements BeforeAllCallback {
+		@Override
+		public void beforeAll(ExtensionContext context) {
+			var value = context.getStore(ExtensionContext.Namespace.GLOBAL).get("testKey");
+			if (!"testValue".equals(value)) {
+				throw new IllegalStateException("Expected 'testValue' but got: " + value);
+			}
+
+			value = context.getStore(StoreScope.LAUNCHER_SESSION, ExtensionContext.Namespace.GLOBAL).get("testKey");
+			if (!"testValue".equals(value)) {
+				throw new IllegalStateException("Expected 'testValue' but got: " + value);
+			}
+		}
+	}
+
+	static class SessionStoringExtension implements BeforeAllCallback {
+		@Override
+		public void beforeAll(ExtensionContext context) {
+			context.getStore(StoreScope.LAUNCHER_SESSION, ExtensionContext.Namespace.GLOBAL).put("testKey",
+				"testValue");
+		}
+	}
+
+	private static class CloseTrackingResource implements AutoCloseable {
+		private static boolean closed = false;
+
+		@Override
+		public void close() {
+			closed = true;
+		}
+
+		public boolean isClosed() {
+			return closed;
+		}
+	}
+
+	private static class SessionResourceStoreUsingExtension implements BeforeAllCallback {
+		@Override
+		public void beforeAll(ExtensionContext context) {
+			CloseTrackingResource sessionResource = new CloseTrackingResource();
+			context.getStore(StoreScope.LAUNCHER_SESSION, ExtensionContext.Namespace.GLOBAL).put("sessionResource",
+				sessionResource);
+		}
+	}
+
+	private static class RequestResourceStoreUsingExtension implements BeforeAllCallback {
+		@Override
+		public void beforeAll(ExtensionContext context) {
+			CloseTrackingResource requestResource = new CloseTrackingResource();
+			context.getStore(StoreScope.EXECUTION_REQUEST, ExtensionContext.Namespace.GLOBAL).put("requestResource",
+				requestResource);
+		}
+	}
+
+	@SuppressWarnings("JUnitMalformedDeclaration")
+	@ExtendWith(SessionResourceStoreUsingExtension.class)
+	static class SessionResourceAutoCloseTestCase {
+
+		@Test
+		void dummyTest() {
+			// Just a placeholder to trigger the extension
+		}
+	}
+
+	@SuppressWarnings("JUnitMalformedDeclaration")
+	@ExtendWith(RequestResourceStoreUsingExtension.class)
+	static class RequestResourceAutoCloseTestCase {
+
+		@Test
+		void dummyTest() {
+			// Just a placeholder to trigger the extension
+		}
+	}
+
+	private static class AutoCloseCheckListener implements LauncherSessionListener {
+		@Override
+		public void launcherSessionClosed(LauncherSession session) {
+			CloseTrackingResource sessionResource = session //
+					.getStore() //
+					.get(Namespace.GLOBAL, "sessionResource", CloseTrackingResource.class);
+
+			assertThat(sessionResource.isClosed()).isFalse();
+		}
 	}
 }
