@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -22,6 +22,7 @@ import static org.junit.platform.commons.util.CollectionUtils.getOnlyElement;
 import static org.junit.platform.engine.TestExecutionResult.successful;
 import static org.junit.platform.engine.discovery.ClassNameFilter.STANDARD_INCLUDE_PATTERN;
 import static org.junit.platform.launcher.core.LauncherFactoryForTestingPurposesOnly.createLauncher;
+import static org.junit.platform.launcher.core.OutputDirectoryCreators.dummyOutputDirectoryCreator;
 import static org.junit.runner.Description.createSuiteDescription;
 import static org.junit.runner.Description.createTestDescription;
 import static org.junit.runner.manipulation.Filter.matchMethodDescription;
@@ -138,7 +139,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getFiltersByType(ClassNameFilter.class);
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 
 			// Excluded by default
 			assertExcludes(filter, "example.MyClass");
@@ -184,7 +185,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getFiltersByType(PackageNameFilter.class);
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertIncludes(filter, "includedpackage1.TestClass");
 			assertIncludes(filter, "includedpackage2.TestClass");
 			assertExcludes(filter, "excludedpackage1.TestClass");
@@ -202,7 +203,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getFiltersByType(PackageNameFilter.class);
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertIncludes(filter, "includedpackage1.TestClass");
 			assertExcludes(filter, "excludedpackage1.TestClass");
 			assertExcludes(filter, "excludedpackage2.TestClass");
@@ -220,7 +221,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getPostDiscoveryFilters();
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertIncludes(filter, testDescriptorWithTags("foo"));
 			assertIncludes(filter, testDescriptorWithTags("bar"));
 			assertExcludes(filter, testDescriptorWithTags("baz"));
@@ -238,7 +239,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getPostDiscoveryFilters();
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertExcludes(filter, testDescriptorWithTags("foo"));
 			assertExcludes(filter, testDescriptorWithTags("bar"));
 			assertIncludes(filter, testDescriptorWithTags("baz"));
@@ -256,7 +257,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getPostDiscoveryFilters();
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertIncludes(filter, testDescriptorWithTags("foo"));
 			assertIncludes(filter, testDescriptorWithTags("foo", "any_other_tag"));
 			assertExcludes(filter, testDescriptorWithTags("foo", "bar"));
@@ -276,7 +277,7 @@ class JUnitPlatformRunnerTests {
 			var filters = request.getPostDiscoveryFilters();
 			assertThat(filters).hasSize(1);
 
-			var filter = filters.get(0);
+			var filter = filters.getFirst();
 			assertExcludes(filter, testDescriptorWithTags("foo"));
 			assertExcludes(filter, testDescriptorWithTags("foo", "any_other_tag"));
 			assertIncludes(filter, testDescriptorWithTags("foo", "bar"));
@@ -308,7 +309,7 @@ class JUnitPlatformRunnerTests {
 			assertIncludes(includeFilter, bazEngine);
 			assertExcludes(includeFilter, quuxEngine);
 
-			var excludeFilter = filters.get(0);
+			var excludeFilter = filters.getFirst();
 			assertIncludes(excludeFilter, fooEngine);
 			assertExcludes(excludeFilter, barEngine);
 			assertIncludes(excludeFilter, bazEngine);
@@ -465,7 +466,7 @@ class JUnitPlatformRunnerTests {
 			TestDescriptor container2 = new TestDescriptorStub(UniqueId.root("root", "container2"), "container2");
 			container2.addChild(new TestDescriptorStub(UniqueId.root("root", "test2a"), "test2a"));
 			container2.addChild(new TestDescriptorStub(UniqueId.root("root", "test2b"), "test2b"));
-			var testPlan = TestPlan.from(List.of(container1, container2), mock());
+			var testPlan = TestPlan.from(true, List.of(container1, container2), mock(), dummyOutputDirectoryCreator());
 
 			var launcher = mock(Launcher.class);
 			when(launcher.discover(any())).thenReturn(testPlan);
@@ -512,11 +513,13 @@ class JUnitPlatformRunnerTests {
 			TestDescriptor originalParent2 = new TestDescriptorStub(UniqueId.root("root", "parent2"), "parent2");
 			originalParent2.addChild(new TestDescriptorStub(UniqueId.root("root", "leaf2a"), "leaf2a"));
 			originalParent2.addChild(new TestDescriptorStub(UniqueId.root("root", "leaf2b"), "leaf2b"));
-			var fullTestPlan = TestPlan.from(List.of(originalParent1, originalParent2), configParams);
+			var fullTestPlan = TestPlan.from(true, List.of(originalParent1, originalParent2), configParams,
+				dummyOutputDirectoryCreator());
 
 			TestDescriptor filteredParent = new TestDescriptorStub(UniqueId.root("root", "parent2"), "parent2");
 			filteredParent.addChild(new TestDescriptorStub(UniqueId.root("root", "leaf2b"), "leaf2b"));
-			var filteredTestPlan = TestPlan.from(Set.of(filteredParent), configParams);
+			var filteredTestPlan = TestPlan.from(true, Set.of(filteredParent), configParams,
+				dummyOutputDirectoryCreator());
 
 			var launcher = mock(Launcher.class);
 			var captor = ArgumentCaptor.forClass(LauncherDiscoveryRequest.class);
@@ -538,8 +541,8 @@ class JUnitPlatformRunnerTests {
 
 		@Test
 		void throwsNoTestsRemainExceptionWhenNoTestIdentifierMatchesFilter() {
-			var testPlan = TestPlan.from(Set.of(new TestDescriptorStub(UniqueId.root("root", "test"), "test")),
-				configParams);
+			var testPlan = TestPlan.from(true, Set.of(new TestDescriptorStub(UniqueId.root("root", "test"), "test")),
+				configParams, dummyOutputDirectoryCreator());
 
 			var launcher = mock(Launcher.class);
 			when(launcher.discover(any())).thenReturn(testPlan);
@@ -694,7 +697,7 @@ class JUnitPlatformRunnerTests {
 
 			List<Description> children = platformRunner.getDescription().getChildren();
 			assertEquals(1, children.size());
-			var engineDescription = children.get(0);
+			var engineDescription = children.getFirst();
 			assertEquals("dummy", engineDescription.getDisplayName());
 
 			var containerDescription = getOnlyElement(engineDescription.getChildren());
@@ -730,7 +733,7 @@ class JUnitPlatformRunnerTests {
 
 			List<Description> children = platformRunner.getDescription().getChildren();
 			assertEquals(1, children.size());
-			var engineDescription = children.get(0);
+			var engineDescription = children.getFirst();
 			assertEquals("dummy", engineDescription.getDisplayName());
 
 			var containerDescription = getOnlyElement(engineDescription.getChildren());
@@ -777,7 +780,8 @@ class JUnitPlatformRunnerTests {
 	private LauncherDiscoveryRequest instantiateRunnerAndCaptureGeneratedRequest(Class<?> testClass) {
 		var launcher = mock(Launcher.class);
 		var captor = ArgumentCaptor.forClass(LauncherDiscoveryRequest.class);
-		when(launcher.discover(captor.capture())).thenReturn(TestPlan.from(Set.of(), mock()));
+		when(launcher.discover(captor.capture())).thenReturn(
+			TestPlan.from(true, Set.of(), mock(), dummyOutputDirectoryCreator()));
 
 		new JUnitPlatform(testClass, launcher);
 
