@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -58,6 +58,7 @@ import org.junit.platform.launcher.EngineFilter;
 import org.junit.platform.launcher.LauncherDiscoveryRequest;
 import org.junit.platform.launcher.PostDiscoveryFilter;
 import org.junit.platform.suite.api.ConfigurationParameter;
+import org.junit.platform.suite.api.ConfigurationParametersResource;
 import org.junit.platform.suite.api.DisableParentConfigurationParameters;
 import org.junit.platform.suite.api.ExcludeClassNamePatterns;
 import org.junit.platform.suite.api.ExcludeEngines;
@@ -67,6 +68,7 @@ import org.junit.platform.suite.api.IncludeClassNamePatterns;
 import org.junit.platform.suite.api.IncludeEngines;
 import org.junit.platform.suite.api.IncludePackages;
 import org.junit.platform.suite.api.IncludeTags;
+import org.junit.platform.suite.api.Select;
 import org.junit.platform.suite.api.SelectClasses;
 import org.junit.platform.suite.api.SelectClasspathResource;
 import org.junit.platform.suite.api.SelectDirectories;
@@ -92,6 +94,48 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		assertEquals(Optional.of("*"), parameter);
 	}
 
+	@Test
+	void configurationParametersResource() {
+		@ConfigurationParametersResource("config-test.properties")
+		class Suite {
+		}
+
+		LauncherDiscoveryRequest request = builder.applyConfigurationParametersFromSuite(Suite.class).build();
+		ConfigurationParameters configuration = request.getConfigurationParameters();
+		Optional<String> parameter = configuration.get("com.example.prop.first");
+		assertEquals(Optional.of("first value"), parameter);
+	}
+
+	@Test
+	void configurationParametersResources() {
+		@ConfigurationParametersResource("config-test.properties")
+		@ConfigurationParametersResource("config-test-override.properties")
+		class Suite {
+		}
+
+		LauncherDiscoveryRequest request = builder.applyConfigurationParametersFromSuite(Suite.class).build();
+		ConfigurationParameters configuration = request.getConfigurationParameters();
+		Optional<String> parameterOne = configuration.get("com.example.prop.first");
+		assertEquals(Optional.of("first value from override file"), parameterOne);
+		Optional<String> parameterTwo = configuration.get("com.example.prop.second");
+		assertEquals(Optional.of("second value"), parameterTwo);
+	}
+
+	@Test
+	void configurationParametersResource_explicitParametersTakePrecedence() {
+		@ConfigurationParametersResource("config-test.properties")
+		@ConfigurationParameter(key = "com.example.prop.first", value = "first value from explicit parameter")
+		class Suite {
+		}
+
+		LauncherDiscoveryRequest request = builder.applyConfigurationParametersFromSuite(Suite.class).build();
+		ConfigurationParameters configuration = request.getConfigurationParameters();
+		Optional<String> parameterOne = configuration.get("com.example.prop.first");
+		assertEquals(Optional.of("first value from explicit parameter"), parameterOne);
+		Optional<String> parameterTwo = configuration.get("com.example.prop.second");
+		assertEquals(Optional.of("second value"), parameterTwo);
+	}
+
 	@Test
 	void excludeClassNamePatterns() {
 		class TestCase {
@@ -585,6 +629,28 @@ class SuiteLauncherDiscoveryRequestBuilderTests {
 		assertEquals(Optional.empty(), configurationParameters.get("parent"));
 	}
 
+	@Test
+	void selectByIdentifier() {
+		// @formatter:off
+		@Select({
+				"class:org.junit.platform.suite.commons.SuiteLauncherDiscoveryRequestBuilderTests$NonLocalTestCase",
+				"method:org.junit.platform.suite.commons.SuiteLauncherDiscoveryRequestBuilderTests$NoParameterTestCase#testMethod"
+		})
+		// @formatter:on
+		class Suite {
+		}
+
+		LauncherDiscoveryRequest request = builder.applySelectorsAndFiltersFromSuite(Suite.class).build();
+		List<ClassSelector> classSelectors = request.getSelectorsByType(ClassSelector.class);
+		assertEquals(NonLocalTestCase.class, exactlyOne(classSelectors).getJavaClass());
+		List<MethodSelector> methodSelectors = request.getSelectorsByType(MethodSelector.class);
+		// @formatter:off
+		assertThat(exactlyOne(methodSelectors))
+				.extracting(MethodSelector::getJavaClass, MethodSelector::getMethodName)
+				.containsExactly(NoParameterTestCase.class, "testMethod");
+		// @formatter:on
+	}
+
 	private static <T> T exactlyOne(List<T> list) {
 		return CollectionUtils.getOnlyElement(list);
 	}
