@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -19,6 +19,9 @@ class JupiterIntegration {
 
 	@Test
 	void successful() {
+		Runtime.getRuntime().addShutdownHook(new Thread(() -> {
+			new other.OtherwiseNotReferencedClass();
+		}));
 	}
 
 	@Test
