@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -23,11 +23,15 @@ public class ThirdPartyJars {
 	}
 
 	public static void copy(Path targetDir, String group, String artifact) throws Exception {
-		Path source = Stream.of(System.getProperty("thirdPartyJars").split(File.pathSeparator)) //
+		Path source = find(group, artifact);
+		Files.copy(source, targetDir.resolve(source.getFileName()), REPLACE_EXISTING);
+	}
+
+	public static Path find(String group, String artifact) {
+		return Stream.of(System.getProperty("thirdPartyJars").split(File.pathSeparator)) //
 				.filter(it -> it.replace(File.separator, "/").contains("/" + group + "/" + artifact + "/")) //
 				.map(Path::of) //
 				.findFirst() //
 				.orElseThrow(() -> new AssertionError("Failed to find JAR file for " + group + ":" + artifact));
-		Files.copy(source, targetDir.resolve(source.getFileName()), REPLACE_EXISTING);
 	}
 }
