@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2024 the original author or authors.
+ * Copyright 2015-2026 the original author or authors.
  *
  * All rights reserved. This program and the accompanying materials are
  * made available under the terms of the Eclipse Public License v2.0 which
@@ -31,28 +31,33 @@ import java.util.List;
 import java.util.ServiceLoader;
 import java.util.Set;
 import java.util.spi.ToolProvider;
-import java.util.stream.Collectors;
 import java.util.stream.StreamSupport;
 
+import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Order;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.condition.OS;
+import org.junit.jupiter.api.extension.DisabledOnOpenJ9;
+import org.junit.jupiter.api.io.TempDir;
 
 import platform.tooling.support.Helper;
 import platform.tooling.support.MavenRepo;
-import platform.tooling.support.Request;
 import platform.tooling.support.ThirdPartyJars;
 
 /**
  * @since 1.6
  */
+@Order(Integer.MAX_VALUE)
 class ToolProviderTests {
 
-	private static final Path LIB = Request.WORKSPACE.resolve("tool-provider-tests/lib");
+	@TempDir
+	static Path lib;
 
 	@BeforeAll
 	static void prepareLocalLibraryDirectoryWithJUnitPlatformModules() {
 		try {
-			var lib = Files.createDirectories(LIB);
+			Files.createDirectories(lib);
 			try (var directoryStream = Files.newDirectoryStream(lib, "*.jar")) {
 				for (Path jarFile : directoryStream) {
 					Files.delete(jarFile);
@@ -66,19 +71,28 @@ class ToolProviderTests {
 			}
 			ThirdPartyJars.copy(lib, "org.apiguardian", "apiguardian-api");
 			ThirdPartyJars.copy(lib, "org.opentest4j", "opentest4j");
+			ThirdPartyJars.copy(lib, "org.opentest4j.reporting", "open-test-reporting-tooling-spi");
 		}
 		catch (Exception e) {
 			throw new AssertionError("Preparing local library folder failed", e);
 		}
 	}
 
+	@AfterAll
+	static void triggerReleaseOfFileHandlesOnWindows() throws Exception {
+		if (OS.current() == OS.WINDOWS) {
+			System.gc();
+			Thread.sleep(1_000);
+		}
+	}
+
 	@Test
 	void findAndRunJUnitOnTheClassPath() {
-		try (var loader = new URLClassLoader("junit", urls(LIB), ClassLoader.getPlatformClassLoader())) {
+		try (var loader = new URLClassLoader("junit", urls(lib), ClassLoader.getPlatformClassLoader())) {
 			var sl = ServiceLoader.load(ToolProvider.class, loader);
 			var junit = StreamSupport.stream(sl.spliterator(), false).filter(p -> p.name().equals("junit")).findFirst();
 
-			assertTrue(junit.isPresent(), "Tool 'junit' not found in: " + LIB);
+			assertTrue(junit.isPresent(), "Tool 'junit' not found in: " + lib);
 			assertJUnitPrintsHelpMessage(junit.get());
 		}
 		catch (IOException e) {
@@ -87,13 +101,14 @@ class ToolProviderTests {
 	}
 
 	@Test
+	@DisabledOnOpenJ9
 	void findAndRunJUnitOnTheModulePath() {
-		var finder = ModuleFinder.of(LIB);
+		var finder = ModuleFinder.of(lib);
 		var modules = finder.findAll().stream() //
 				.map(ModuleReference::descriptor) //
 				.map(ModuleDescriptor::toNameAndVersion) //
 				.sorted() //
-				.collect(Collectors.toList());
+				.toList();
 		// modules.forEach(System.out::println);
 
 		var bootLayer = ModuleLayer.boot();
@@ -135,7 +150,7 @@ class ToolProviderTests {
 			">> USAGE >>", //
 			"Launches the JUnit Platform for test discovery and execution.", //
 			">> OPTIONS >>"), //
-			out.toString().lines().collect(Collectors.toList())), //
+			out.toString().lines().toList()), //
 			() -> assertEquals("", err.toString()), //
 			() -> assertEquals(0, code, "Expected exit of 0, but got: " + code) //
 		);
